# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/clarifai/api/common.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/clarifai/api/common.proto',
  package='clarifai.api',
  syntax='proto3',
  serialized_pb=_b('\n\x1fproto/clarifai/api/common.proto\x12\x0c\x63larifai.api\"/\n\x0cUserAppIDSet\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\tB$Z\x03\x61pi\xa2\x02\x04\x43\x41IP\xc2\x02\x01_\xca\x02\x11\x43larifai\\Internalb\x06proto3')
)




_USERAPPIDSET = _descriptor.Descriptor(
  name='UserAppIDSet',
  full_name='clarifai.api.UserAppIDSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='clarifai.api.UserAppIDSet.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='clarifai.api.UserAppIDSet.app_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=49,
  serialized_end=96,
)

DESCRIPTOR.message_types_by_name['UserAppIDSet'] = _USERAPPIDSET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UserAppIDSet = _reflection.GeneratedProtocolMessageType('UserAppIDSet', (_message.Message,), dict(
  DESCRIPTOR = _USERAPPIDSET,
  __module__ = 'proto.clarifai.api.common_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.UserAppIDSet)
  ))
_sym_db.RegisterMessage(UserAppIDSet)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('Z\003api\242\002\004CAIP\302\002\001_\312\002\021Clarifai\\Internal'))
# @@protoc_insertion_point(module_scope)
