# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/clarifai/api/subscription.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from clarifai.rest.grpc.proto.clarifai.api.status import status_pb2 as proto_dot_clarifai_dot_api_dot_status_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/clarifai/api/subscription.proto',
  package='clarifai.api',
  syntax='proto3',
  serialized_pb=_b('\n%proto/clarifai/api/subscription.proto\x12\x0c\x63larifai.api\x1a&proto/clarifai/api/status/status.proto\"\x14\n\x04Plan\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x18\n\x16GetSubscriptionRequest\"P\n\x17PostSubscriptionRequest\x12\x13\n\x0bsignup_code\x18\x01 \x01(\t\x12 \n\x04plan\x18\x02 \x01(\x0b\x32\x12.clarifai.api.Plan\"\x80\x01\n\x1aSingleSubscriptionResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.clarifai.api.status.Status\x12 \n\x04plan\x18\x02 \x01(\x0b\x32\x12.clarifai.api.Plan\x12\x13\n\x0bsignup_code\x18\x03 \x01(\tB$Z\x03\x61pi\xa2\x02\x04\x43\x41IP\xc2\x02\x01_\xca\x02\x11\x43larifai\\Internalb\x06proto3')
  ,
  dependencies=[proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.DESCRIPTOR,])




_PLAN = _descriptor.Descriptor(
  name='Plan',
  full_name='clarifai.api.Plan',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='clarifai.api.Plan.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=115,
)


_GETSUBSCRIPTIONREQUEST = _descriptor.Descriptor(
  name='GetSubscriptionRequest',
  full_name='clarifai.api.GetSubscriptionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=117,
  serialized_end=141,
)


_POSTSUBSCRIPTIONREQUEST = _descriptor.Descriptor(
  name='PostSubscriptionRequest',
  full_name='clarifai.api.PostSubscriptionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='signup_code', full_name='clarifai.api.PostSubscriptionRequest.signup_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plan', full_name='clarifai.api.PostSubscriptionRequest.plan', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=143,
  serialized_end=223,
)


_SINGLESUBSCRIPTIONRESPONSE = _descriptor.Descriptor(
  name='SingleSubscriptionResponse',
  full_name='clarifai.api.SingleSubscriptionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='clarifai.api.SingleSubscriptionResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plan', full_name='clarifai.api.SingleSubscriptionResponse.plan', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signup_code', full_name='clarifai.api.SingleSubscriptionResponse.signup_code', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=226,
  serialized_end=354,
)

_POSTSUBSCRIPTIONREQUEST.fields_by_name['plan'].message_type = _PLAN
_SINGLESUBSCRIPTIONRESPONSE.fields_by_name['status'].message_type = proto_dot_clarifai_dot_api_dot_status_dot_status__pb2._STATUS
_SINGLESUBSCRIPTIONRESPONSE.fields_by_name['plan'].message_type = _PLAN
DESCRIPTOR.message_types_by_name['Plan'] = _PLAN
DESCRIPTOR.message_types_by_name['GetSubscriptionRequest'] = _GETSUBSCRIPTIONREQUEST
DESCRIPTOR.message_types_by_name['PostSubscriptionRequest'] = _POSTSUBSCRIPTIONREQUEST
DESCRIPTOR.message_types_by_name['SingleSubscriptionResponse'] = _SINGLESUBSCRIPTIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Plan = _reflection.GeneratedProtocolMessageType('Plan', (_message.Message,), dict(
  DESCRIPTOR = _PLAN,
  __module__ = 'proto.clarifai.api.subscription_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.Plan)
  ))
_sym_db.RegisterMessage(Plan)

GetSubscriptionRequest = _reflection.GeneratedProtocolMessageType('GetSubscriptionRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETSUBSCRIPTIONREQUEST,
  __module__ = 'proto.clarifai.api.subscription_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.GetSubscriptionRequest)
  ))
_sym_db.RegisterMessage(GetSubscriptionRequest)

PostSubscriptionRequest = _reflection.GeneratedProtocolMessageType('PostSubscriptionRequest', (_message.Message,), dict(
  DESCRIPTOR = _POSTSUBSCRIPTIONREQUEST,
  __module__ = 'proto.clarifai.api.subscription_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.PostSubscriptionRequest)
  ))
_sym_db.RegisterMessage(PostSubscriptionRequest)

SingleSubscriptionResponse = _reflection.GeneratedProtocolMessageType('SingleSubscriptionResponse', (_message.Message,), dict(
  DESCRIPTOR = _SINGLESUBSCRIPTIONRESPONSE,
  __module__ = 'proto.clarifai.api.subscription_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.SingleSubscriptionResponse)
  ))
_sym_db.RegisterMessage(SingleSubscriptionResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('Z\003api\242\002\004CAIP\302\002\001_\312\002\021Clarifai\\Internal'))
# @@protoc_insertion_point(module_scope)
