# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/clarifai/api/usage_interval_type.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/clarifai/api/usage_interval_type.proto',
  package='clarifai.api',
  syntax='proto3',
  serialized_pb=_b('\n,proto/clarifai/api/usage_interval_type.proto\x12\x0c\x63larifai.api*<\n\x11UsageIntervalType\x12\t\n\x05undef\x10\x00\x12\x07\n\x03\x64\x61y\x10\x01\x12\t\n\x05month\x10\x02\x12\x08\n\x04year\x10\x03\x42$Z\x03\x61pi\xa2\x02\x04\x43\x41IP\xc2\x02\x01_\xca\x02\x11\x43larifai\\Internalb\x06proto3')
)

_USAGEINTERVALTYPE = _descriptor.EnumDescriptor(
  name='UsageIntervalType',
  full_name='clarifai.api.UsageIntervalType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='undef', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='day', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='month', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='year', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=62,
  serialized_end=122,
)
_sym_db.RegisterEnumDescriptor(_USAGEINTERVALTYPE)

UsageIntervalType = enum_type_wrapper.EnumTypeWrapper(_USAGEINTERVALTYPE)
undef = 0
day = 1
month = 2
year = 3


DESCRIPTOR.enum_types_by_name['UsageIntervalType'] = _USAGEINTERVALTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('Z\003api\242\002\004CAIP\302\002\001_\312\002\021Clarifai\\Internal'))
# @@protoc_insertion_point(module_scope)
