# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/clarifai/utils/jsonpb/test.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/clarifai/utils/jsonpb/test.proto',
  package='jsonpb',
  syntax='proto3',
  serialized_pb=_b('\n&proto/clarifai/utils/jsonpb/test.proto\x12\x06jsonpb\"\x7f\n\x14\x42oolFloatTestMessage\x12\x0f\n\x07uint_32\x18\x04 \x01(\r\x12\x0f\n\x07uint_64\x18\x05 \x01(\x04\x12\x0e\n\x06int_32\x18\x06 \x01(\x05\x12\x0e\n\x06int_64\x18\x07 \x01(\x03\x12\x0c\n\x04\x66_32\x18\x08 \x01(\x02\x12\x0c\n\x04\x66_64\x18\t \x01(\x01\x12\t\n\x01\x62\x18\n \x01(\x08\x62\x06proto3')
)




_BOOLFLOATTESTMESSAGE = _descriptor.Descriptor(
  name='BoolFloatTestMessage',
  full_name='jsonpb.BoolFloatTestMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uint_32', full_name='jsonpb.BoolFloatTestMessage.uint_32', index=0,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uint_64', full_name='jsonpb.BoolFloatTestMessage.uint_64', index=1,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='int_32', full_name='jsonpb.BoolFloatTestMessage.int_32', index=2,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='int_64', full_name='jsonpb.BoolFloatTestMessage.int_64', index=3,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='f_32', full_name='jsonpb.BoolFloatTestMessage.f_32', index=4,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='f_64', full_name='jsonpb.BoolFloatTestMessage.f_64', index=5,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='b', full_name='jsonpb.BoolFloatTestMessage.b', index=6,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=50,
  serialized_end=177,
)

DESCRIPTOR.message_types_by_name['BoolFloatTestMessage'] = _BOOLFLOATTESTMESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BoolFloatTestMessage = _reflection.GeneratedProtocolMessageType('BoolFloatTestMessage', (_message.Message,), dict(
  DESCRIPTOR = _BOOLFLOATTESTMESSAGE,
  __module__ = 'proto.clarifai.utils.jsonpb.test_pb2'
  # @@protoc_insertion_point(class_scope:jsonpb.BoolFloatTestMessage)
  ))
_sym_db.RegisterMessage(BoolFloatTestMessage)


# @@protoc_insertion_point(module_scope)
