# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/clarifai/api/status/status_code.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/clarifai/api/status/status_code.proto',
  package='clarifai.api.status',
  syntax='proto3',
  serialized_pb=_b('\n+proto/clarifai/api/status/status_code.proto\x12\x13\x63larifai.api.status*\xab,\n\nStatusCode\x12\x08\n\x04ZERO\x10\x00\x12\x0c\n\x07SUCCESS\x10\x90N\x12\x11\n\x0cMIXED_STATUS\x10\x9aN\x12\x0c\n\x07\x46\x41ILURE\x10\xa4N\x12\x18\n\x13\x43ONN_ACCOUNT_ISSUES\x10\xf8U\x12\x17\n\x12\x43ONN_TOKEN_INVALID\x10\xf9U\x12\x1d\n\x18\x43ONN_CREDENTIALS_INVALID\x10\xfaU\x12\x1d\n\x18\x43ONN_EXCEED_HOURLY_LIMIT\x10\xfbU\x12\x1e\n\x19\x43ONN_EXCEED_MONTHLY_LIMIT\x10\xfcU\x12\x13\n\x0e\x43ONN_THROTTLED\x10\xfdU\x12\x18\n\x13\x43ONN_EXCEEDS_LIMITS\x10\xfeU\x12\x1d\n\x18\x43ONN_INSUFFICIENT_SCOPES\x10\xffU\x12\x15\n\x10\x43ONN_KEY_INVALID\x10\x80V\x12\x17\n\x12\x43ONN_KEY_NOT_FOUND\x10\x81V\x12\x1c\n\x17\x43ONN_BAD_REQUEST_FORMAT\x10\xdcV\x12\x18\n\x13\x43ONN_DOES_NOT_EXIST\x10\xddV\x12\x19\n\x14\x43ONN_INVALID_REQUEST\x10\xdeV\x12\x1c\n\x17\x43ONN_METHOD_NOT_ALLOWED\x10\xdfV\x12\x13\n\rMODEL_TRAINED\x10\xec\xa4\x01\x12\x14\n\x0eMODEL_TRAINING\x10\xed\xa4\x01\x12\x15\n\x0fMODEL_UNTRAINED\x10\xee\xa4\x01\x12\x1f\n\x19MODEL_QUEUED_FOR_TRAINING\x10\xef\xa4\x01\x12\x1c\n\x16MODEL_TRAINING_NO_DATA\x10\xf6\xa4\x01\x12!\n\x1bMODEL_TRAINING_NO_POSITIVES\x10\xf7\xa4\x01\x12*\n$MODEL_TRAINING_ONE_VS_N_SINGLE_CLASS\x10\xf8\xa4\x01\x12\x1e\n\x18MODEL_TRAINING_TIMED_OUT\x10\xf9\xa4\x01\x12\"\n\x1cMODEL_TRAINING_WAITING_ERROR\x10\xfa\xa4\x01\x12\"\n\x1cMODEL_TRAINING_UNKNOWN_ERROR\x10\xfb\xa4\x01\x12\"\n\x1cMODEL_TRAINING_MSG_REDELIVER\x10\xfc\xa4\x01\x12\x1a\n\x14MODEL_MODIFY_SUCCESS\x10\x9e\xa5\x01\x12\x1a\n\x14MODEL_MODIFY_PENDING\x10\x9f\xa5\x01\x12\x19\n\x13MODEL_MODIFY_FAILED\x10\xa0\xa5\x01\x12\x1a\n\x14MODEL_DOES_NOT_EXIST\x10\xd0\xa5\x01\x12\x1d\n\x17MODEL_PERMISSION_DENIED\x10\xd1\xa5\x01\x12\x1c\n\x16MODEL_INVALID_ARGUMENT\x10\xd2\xa5\x01\x12\x1b\n\x15MODEL_INVALID_REQUEST\x10\xd3\xa5\x01\x12\x15\n\x0fMODEL_EVALUATED\x10\xb4\xa6\x01\x12\x16\n\x10MODEL_EVALUATING\x10\xb5\xa6\x01\x12\x19\n\x13MODEL_NOT_EVALUATED\x10\xb6\xa6\x01\x12!\n\x1bMODEL_QUEUED_FOR_EVALUATION\x10\xb7\xa6\x01\x12 \n\x1aMODEL_EVALUATION_TIMED_OUT\x10\xbe\xa6\x01\x12$\n\x1eMODEL_EVALUATION_WAITING_ERROR\x10\xbf\xa6\x01\x12$\n\x1eMODEL_EVALUATION_UNKNOWN_ERROR\x10\xc0\xa6\x01\x12\x1d\n\x17MODEL_PREDICTION_FAILED\x10\xc1\xa6\x01\x12$\n\x1eMODEL_EVALUATION_MSG_REDELIVER\x10\xc2\xa6\x01\x12\"\n\x1cMODEL_EVALUATION_NEED_LABELS\x10\xc3\xa6\x01\x12\"\n\x1cMODEL_EVALUATION_NEED_INPUTS\x10\xc4\xa6\x01\x12 \n\x1aWORKFLOW_NO_MATCHING_INPUT\x10\xf1\xab\x01\x12$\n\x1eWORKFLOW_REQUIRE_TRAINED_MODEL\x10\xf2\xab\x01\x12\x18\n\x12WORKFLOW_DUPLICATE\x10\xd4\xac\x01\x12!\n\x1bWORKFLOW_UNSUPPORTED_FORMAT\x10\xd5\xac\x01\x12\x1d\n\x17WORKFLOW_DOES_NOT_EXIST\x10\xd6\xac\x01\x12 \n\x1aWORKFLOW_PERMISSION_DENIED\x10\xd7\xac\x01\x12\x1f\n\x19WORKFLOW_INVALID_ARGUMENT\x10\xd8\xac\x01\x12\x1d\n\x17WORKFLOW_INVALID_RECIPE\x10\xd9\xac\x01\x12\x1f\n\x19WORKFLOW_INVALID_TEMPLATE\x10\xda\xac\x01\x12\x1c\n\x16WORKFLOW_INVALID_GRAPH\x10\xdb\xac\x01\x12\x1f\n\x19WORKFLOW_INTERNAL_FAILURE\x10\xdc\xac\x01\x12\x1e\n\x18WORKFLOW_INVALID_REQUEST\x10\xd7\xb3\x01\x12\x1d\n\x17WORKFLOW_MODIFY_SUCCESS\x10\x86\xad\x01\x12\x1d\n\x17WORKFLOW_MODIFY_PENDING\x10\x87\xad\x01\x12\x1c\n\x16WORKFLOW_MODIFY_FAILED\x10\x88\xad\x01\x12\x1c\n\x16\x43ONCEPT_MODIFY_SUCCESS\x10\xee\xb4\x01\x12\x1c\n\x16\x43ONCEPT_MODIFY_PENDING\x10\xef\xb4\x01\x12\x1b\n\x15\x43ONCEPT_MODIFY_FAILED\x10\xf0\xb4\x01\x12\x18\n\x12\x41NNOTATION_SUCCESS\x10\xd6\xbc\x01\x12\x18\n\x12\x41NNOTATION_PENDING\x10\xd7\xbc\x01\x12\x17\n\x11\x41NNOTATION_FAILED\x10\xd8\xbc\x01\x12\x1c\n\x16\x41NNOTATION_IN_PROGRESS\x10\xd9\xbc\x01\x12\"\n\x1cINPUT_IMAGE_DOWNLOAD_SUCCESS\x10\xb0\xea\x01\x12\"\n\x1cINPUT_IMAGE_DOWNLOAD_PENDING\x10\xb1\xea\x01\x12!\n\x1bINPUT_IMAGE_DOWNLOAD_FAILED\x10\xb2\xea\x01\x12&\n INPUT_IMAGE_DOWNLOAD_IN_PROGRESS\x10\xb3\xea\x01\x12&\n INPUT_IMAGE_STATUS_UPDATE_FAILED\x10\xb4\xea\x01\x12\x1f\n\x19INPUT_IMAGE_DELETE_FAILED\x10\xb5\xea\x01\x12\x1b\n\x15INPUT_IMAGE_DUPLICATE\x10\x94\xeb\x01\x12$\n\x1eINPUT_IMAGE_UNSUPPORTED_FORMAT\x10\x95\xeb\x01\x12 \n\x1aINPUT_IMAGE_DOES_NOT_EXIST\x10\x96\xeb\x01\x12#\n\x1dINPUT_IMAGE_PERMISSION_DENIED\x10\x97\xeb\x01\x12\"\n\x1cINPUT_IMAGE_INVALID_ARGUMENT\x10\x98\xeb\x01\x12 \n\x1aINPUT_IMAGE_MODIFY_SUCCESS\x10\xf8\xeb\x01\x12 \n\x1aINPUT_IMAGE_MODIFY_PENDING\x10\xf9\xeb\x01\x12\x1f\n\x19INPUT_IMAGE_MODIFY_FAILED\x10\xfb\xeb\x01\x12$\n\x1e\x41LL_INPUT_IMAGES_INVALID_BYTES\x10\xdc\xec\x01\x12!\n\x1bINPUT_IMAGE_CLUSTER_SUCCESS\x10\xc0\xed\x01\x12!\n\x1bINPUT_IMAGE_CLUSTER_PENDING\x10\xc1\xed\x01\x12 \n\x1aINPUT_IMAGE_CLUSTER_FAILED\x10\xc2\xed\x01\x12%\n\x1fINPUT_IMAGE_CLUSTER_IN_PROGRESS\x10\xc3\xed\x01\x12\"\n\x1cINPUT_VIDEO_DOWNLOAD_SUCCESS\x10\x98\xf2\x01\x12\"\n\x1cINPUT_VIDEO_DOWNLOAD_PENDING\x10\x99\xf2\x01\x12!\n\x1bINPUT_VIDEO_DOWNLOAD_FAILED\x10\x9a\xf2\x01\x12\x1b\n\x15INPUT_VIDEO_DUPLICATE\x10\xfc\xf2\x01\x12$\n\x1eINPUT_VIDEO_UNSUPPORTED_FORMAT\x10\xfd\xf2\x01\x12 \n\x1aINPUT_VIDEO_DOES_NOT_EXIST\x10\xfe\xf2\x01\x12#\n\x1dINPUT_VIDEO_PERMISSION_DENIED\x10\xff\xf2\x01\x12\"\n\x1cINPUT_VIDEO_INVALID_ARGUMENT\x10\x80\xf3\x01\x12 \n\x1aINPUT_VIDEO_MODIFY_SUCCESS\x10\xe0\xf3\x01\x12 \n\x1aINPUT_VIDEO_MODIFY_PENDING\x10\xe1\xf3\x01\x12\x1f\n\x19INPUT_VIDEO_MODIFY_FAILED\x10\xe3\xf3\x01\x12&\n REQUEST_DISABLED_FOR_MAINTENANCE\x10\xbd\xb8\x02\x12+\n%INPUT_WRITES_DISABLED_FOR_MAINTENANCE\x10\xbe\xb8\x02\x12\x1b\n\x15INPUT_INVALID_REQUEST\x10\xbf\xb8\x02\x12\x1d\n\x17PREDICT_INVALID_REQUEST\x10\xc1\xb8\x02\x12\x1c\n\x16SEARCH_INVALID_REQUEST\x10\xc2\xb8\x02\x12\x1e\n\x18\x43ONCEPTS_INVALID_REQUEST\x10\xc3\xb8\x02\x12\x1c\n\x16\x44\x41TABASE_DUPLICATE_KEY\x10\xca\xb8\x02\x12 \n\x1a\x44\x41TABASE_STATEMENT_TIMEOUT\x10\xcb\xb8\x02\x12$\n\x1e\x44\x41TABASE_INVALID_ROWS_AFFECTED\x10\xcc\xb8\x02\x12 \n\x1a\x44\x41TABASE_DEADLOCK_DETECTED\x10\xcd\xb8\x02\x12\x18\n\x12\x44\x41TABASE_FAIL_TASK\x10\xce\xb8\x02\x12&\n DATABASE_FAIL_TO_GET_CONNECTIONS\x10\xcf\xb8\x02\x12\x1f\n\x19\x44\x41TABASE_TOO_MANY_CLIENTS\x10\xd0\xb8\x02\x12\"\n\x1c\x44\x41TABASE_CONSTRAINT_VIOLATED\x10\xd1\xb8\x02\x12\x1f\n\x19\x41SYNC_WORKER_MULTI_ERRORS\x10\xd4\xb8\x02\x12\x1c\n\x16RPC_REQUEST_QUEUE_FULL\x10\xde\xb8\x02\x12\x1c\n\x16RPC_SERVER_UNAVAILABLE\x10\xdf\xb8\x02\x12\x19\n\x13RPC_REQUEST_TIMEOUT\x10\xe0\xb8\x02\x12#\n\x1dRPC_MAX_MESSAGE_SIZE_EXCEEDED\x10\xe1\xb8\x02\x12\x12\n\x0cRPC_CANCELED\x10\xe3\xb8\x02\x12\x1e\n\x18\x43LUSTER_INTERNAL_FAILURE\x10\xa0\xd0\x02\x12\x1f\n\x19\x45XTERNAL_CONNECTION_ERROR\x10\xe2\xb8\x02\x12\x16\n\x10QUEUE_CONN_ERROR\x10\xa8\xc0\x02\x12!\n\x1bQUEUE_CLOSE_REQUEST_TIMEOUT\x10\xaa\xc0\x02\x12\x17\n\x11QUEUE_CONN_CLOSED\x10\xab\xc0\x02\x12\x1f\n\x19QUEUE_PUBLISH_ACK_TIMEOUT\x10\xac\xc0\x02\x12\x19\n\x13QUEUE_PUBLISH_ERROR\x10\xad\xc0\x02\x12 \n\x1aQUEUE_SUBSCRIPTION_TIMEOUT\x10\xae\xc0\x02\x12\x1e\n\x18QUEUE_SUBSCRIPTION_ERROR\x10\xaf\xc0\x02\x12\x1e\n\x18QUEUE_MARSHALLING_FAILED\x10\xb0\xc0\x02\x12 \n\x1aQUEUE_UNMARSHALLING_FAILED\x10\xb1\xc0\x02\x12\'\n!QUEUE_MAX_MSG_REDELIVERY_EXCEEDED\x10\xb2\xc0\x02\x12\x17\n\x11QUEUE_ACK_FAILURE\x10\xb3\xc0\x02\x12\x13\n\rSQS_OVERLIMIT\x10\x8c\xc1\x02\x12 \n\x1aSQS_INVALID_RECEIPT_HANDLE\x10\x8d\xc1\x02\x12\x11\n\x0bSQS_UNKNOWN\x10\x8e\xc1\x02\x12\x1b\n\x15VISUALIZATION_SUCCESS\x10\x90\xc8\x02\x12\x1b\n\x15VISUALIZATION_PENDING\x10\x91\xc8\x02\x12\x1a\n\x14VISUALIZATION_FAILED\x10\x92\xc8\x02\x12#\n\x1dVISUALIZATION_INVALID_REQUEST\x10\x93\xc8\x02\x12\x1f\n\x19MISSING_APP_VISUALIZATION\x10\x94\xc8\x02\x12!\n\x1bVISUALIZATION_TOO_MANY_URLS\x10\x95\xc8\x02\x12(\n\"VISUALIZATION_FAILED_TO_SAMPLE_APP\x10\x96\xc8\x02\x12#\n\x1dVISUALIZATION_FAILED_TO_EMBED\x10\x97\xc8\x02\x12\x1c\n\x16VISUALIZATION_S3_ERROR\x10\x98\xc8\x02\x12\x1d\n\x17SEARCH_INTERNAL_FAILURE\x10\xf9\xcf\x02\x12\x1f\n\x19SEARCH_PROJECTION_FAILURE\x10\xfa\xcf\x02\x12\x1f\n\x19SEARCH_PREDICTION_FAILURE\x10\xfb\xcf\x02\x12\'\n!SEARCH_BY_NOT_FULLY_INDEXED_INPUT\x10\xfc\xcf\x02\x12\x18\n\x12STRIPE_EVENT_ERROR\x10\xe1\xd7\x02\x12\x10\n\nCACHE_MISS\x10\xc9\xdf\x02\x12&\n REDIS_SCRIPT_EXITED_WITH_FAILURE\x10\xca\xdf\x02\x12\x18\n\x12SIGNUP_EVENT_ERROR\x10\xb1\xe7\x02\x12\x14\n\x0eSIGNUP_FLAGGED\x10\xb2\xe7\x02\x12\x1f\n\x19\x41PP_COUNT_INVALID_MESSAGE\x10\x99\xef\x02\x12\'\n!APP_COUNT_UPDATE_INCREMENT_FAILED\x10\x9a\xef\x02\x12\x1e\n\x18\x41PP_COUNT_REBUILD_FAILED\x10\x9b\xef\x02\x12 \n\x1a\x41PP_COUNT_INTERNAL_FAILURE\x10\x9c\xef\x02\x12\x17\n\x11MP_DOWNLOAD_ERROR\x10\xfd\xef\x02\x12\x1a\n\x14MP_RESOLVE_DNS_ERROR\x10\xfe\xef\x02\x12)\n#MP_DOWNLOAD_MAX_SIZE_EXCEEDED_ERROR\x10\xff\xef\x02\x12\x1b\n\x15MP_IMAGE_DECODE_ERROR\x10\x80\xf0\x02\x12\x19\n\x13MP_INVALID_ARGUMENT\x10\x81\xf0\x02\x12\x1f\n\x19MP_IMAGE_PROCESSING_ERROR\x10\x82\xf0\x02\x12\x18\n\x12USER_CONSERNT_FACE\x10\xd1\x86\x03\x12\x13\n\rWORKER_ACTIVE\x10\xb9\x8e\x03\x12\x15\n\x0fWORKER_INACTIVE\x10\xba\x8e\x03\x12\x1b\n\x15INTERNAL_SERVER_ISSUE\x10\xd4\xfd\x05\x12\x1d\n\x17INTERNAL_FETCHING_ISSUE\x10\xd5\xfd\x05\x12\x1d\n\x17INTERNAL_DATABASE_ISSUE\x10\xd6\xfd\x05\x12!\n\x1bINTERNAL_UNEXPECTED_TIMEOUT\x10\xd9\xfd\x05\x12\x1c\n\x16INTERNAL_UNEXPECTED_V1\x10\xda\xfd\x05\x12\x1f\n\x19INTERNAL_UNEXPECTED_PANIC\x10\xdb\xfd\x05\x12\x1f\n\x19INTERNAL_UNEXPECTED_SPIRE\x10\xdc\xfd\x05\x12 \n\x1aINTERNAL_REDIS_UNAVAILABLE\x10\xdd\xfd\x05\x12!\n\x1bINTERNAL_RESOURCE_EXHAUSTED\x10\xde\xfd\x05\x12\"\n\x1cINTERNAL_REDIS_UNCATEGORIZED\x10\xdf\xfd\x05\x12\x18\n\x12\x43ONN_UNCATEGORIZED\x10\xb9\x85\x06\x12\x19\n\x13MODEL_UNCATEGORIZED\x10\xba\x85\x06\x12\x19\n\x13INPUT_UNCATEGORIZED\x10\xbb\x85\x06\x12\x1c\n\x16INTERNAL_UNCATEGORIZED\x10\xc1\x85\x06\x12\x11\n\x0b\x42\x41\x44_REQUEST\x10\xa0\xc2\x05\x12\x12\n\x0cSERVER_ERROR\x10\x84\xc3\x05\x42.Z\x06status\xa2\x02\x04\x43\x41IP\xc2\x02\x01_\xca\x02\x18\x43larifai\\Internal\\Statusb\x06proto3')
)

_STATUSCODE = _descriptor.EnumDescriptor(
  name='StatusCode',
  full_name='clarifai.api.status.StatusCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ZERO', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=1, number=10000,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MIXED_STATUS', index=2, number=10010,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE', index=3, number=10020,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONN_ACCOUNT_ISSUES', index=4, number=11000,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONN_TOKEN_INVALID', index=5, number=11001,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONN_CREDENTIALS_INVALID', index=6, number=11002,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONN_EXCEED_HOURLY_LIMIT', index=7, number=11003,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONN_EXCEED_MONTHLY_LIMIT', index=8, number=11004,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONN_THROTTLED', index=9, number=11005,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONN_EXCEEDS_LIMITS', index=10, number=11006,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONN_INSUFFICIENT_SCOPES', index=11, number=11007,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONN_KEY_INVALID', index=12, number=11008,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONN_KEY_NOT_FOUND', index=13, number=11009,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONN_BAD_REQUEST_FORMAT', index=14, number=11100,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONN_DOES_NOT_EXIST', index=15, number=11101,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONN_INVALID_REQUEST', index=16, number=11102,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONN_METHOD_NOT_ALLOWED', index=17, number=11103,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL_TRAINED', index=18, number=21100,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL_TRAINING', index=19, number=21101,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL_UNTRAINED', index=20, number=21102,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL_QUEUED_FOR_TRAINING', index=21, number=21103,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL_TRAINING_NO_DATA', index=22, number=21110,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL_TRAINING_NO_POSITIVES', index=23, number=21111,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL_TRAINING_ONE_VS_N_SINGLE_CLASS', index=24, number=21112,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL_TRAINING_TIMED_OUT', index=25, number=21113,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL_TRAINING_WAITING_ERROR', index=26, number=21114,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL_TRAINING_UNKNOWN_ERROR', index=27, number=21115,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL_TRAINING_MSG_REDELIVER', index=28, number=21116,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL_MODIFY_SUCCESS', index=29, number=21150,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL_MODIFY_PENDING', index=30, number=21151,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL_MODIFY_FAILED', index=31, number=21152,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL_DOES_NOT_EXIST', index=32, number=21200,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL_PERMISSION_DENIED', index=33, number=21201,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL_INVALID_ARGUMENT', index=34, number=21202,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL_INVALID_REQUEST', index=35, number=21203,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL_EVALUATED', index=36, number=21300,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL_EVALUATING', index=37, number=21301,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL_NOT_EVALUATED', index=38, number=21302,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL_QUEUED_FOR_EVALUATION', index=39, number=21303,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL_EVALUATION_TIMED_OUT', index=40, number=21310,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL_EVALUATION_WAITING_ERROR', index=41, number=21311,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL_EVALUATION_UNKNOWN_ERROR', index=42, number=21312,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL_PREDICTION_FAILED', index=43, number=21313,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL_EVALUATION_MSG_REDELIVER', index=44, number=21314,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL_EVALUATION_NEED_LABELS', index=45, number=21315,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL_EVALUATION_NEED_INPUTS', index=46, number=21316,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WORKFLOW_NO_MATCHING_INPUT', index=47, number=22001,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WORKFLOW_REQUIRE_TRAINED_MODEL', index=48, number=22002,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WORKFLOW_DUPLICATE', index=49, number=22100,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WORKFLOW_UNSUPPORTED_FORMAT', index=50, number=22101,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WORKFLOW_DOES_NOT_EXIST', index=51, number=22102,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WORKFLOW_PERMISSION_DENIED', index=52, number=22103,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WORKFLOW_INVALID_ARGUMENT', index=53, number=22104,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WORKFLOW_INVALID_RECIPE', index=54, number=22105,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WORKFLOW_INVALID_TEMPLATE', index=55, number=22106,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WORKFLOW_INVALID_GRAPH', index=56, number=22107,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WORKFLOW_INTERNAL_FAILURE', index=57, number=22108,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WORKFLOW_INVALID_REQUEST', index=58, number=22999,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WORKFLOW_MODIFY_SUCCESS', index=59, number=22150,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WORKFLOW_MODIFY_PENDING', index=60, number=22151,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WORKFLOW_MODIFY_FAILED', index=61, number=22152,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONCEPT_MODIFY_SUCCESS', index=62, number=23150,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONCEPT_MODIFY_PENDING', index=63, number=23151,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONCEPT_MODIFY_FAILED', index=64, number=23152,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ANNOTATION_SUCCESS', index=65, number=24150,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ANNOTATION_PENDING', index=66, number=24151,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ANNOTATION_FAILED', index=67, number=24152,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ANNOTATION_IN_PROGRESS', index=68, number=24153,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INPUT_IMAGE_DOWNLOAD_SUCCESS', index=69, number=30000,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INPUT_IMAGE_DOWNLOAD_PENDING', index=70, number=30001,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INPUT_IMAGE_DOWNLOAD_FAILED', index=71, number=30002,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INPUT_IMAGE_DOWNLOAD_IN_PROGRESS', index=72, number=30003,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INPUT_IMAGE_STATUS_UPDATE_FAILED', index=73, number=30004,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INPUT_IMAGE_DELETE_FAILED', index=74, number=30005,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INPUT_IMAGE_DUPLICATE', index=75, number=30100,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INPUT_IMAGE_UNSUPPORTED_FORMAT', index=76, number=30101,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INPUT_IMAGE_DOES_NOT_EXIST', index=77, number=30102,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INPUT_IMAGE_PERMISSION_DENIED', index=78, number=30103,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INPUT_IMAGE_INVALID_ARGUMENT', index=79, number=30104,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INPUT_IMAGE_MODIFY_SUCCESS', index=80, number=30200,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INPUT_IMAGE_MODIFY_PENDING', index=81, number=30201,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INPUT_IMAGE_MODIFY_FAILED', index=82, number=30203,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALL_INPUT_IMAGES_INVALID_BYTES', index=83, number=30300,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INPUT_IMAGE_CLUSTER_SUCCESS', index=84, number=30400,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INPUT_IMAGE_CLUSTER_PENDING', index=85, number=30401,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INPUT_IMAGE_CLUSTER_FAILED', index=86, number=30402,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INPUT_IMAGE_CLUSTER_IN_PROGRESS', index=87, number=30403,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INPUT_VIDEO_DOWNLOAD_SUCCESS', index=88, number=31000,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INPUT_VIDEO_DOWNLOAD_PENDING', index=89, number=31001,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INPUT_VIDEO_DOWNLOAD_FAILED', index=90, number=31002,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INPUT_VIDEO_DUPLICATE', index=91, number=31100,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INPUT_VIDEO_UNSUPPORTED_FORMAT', index=92, number=31101,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INPUT_VIDEO_DOES_NOT_EXIST', index=93, number=31102,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INPUT_VIDEO_PERMISSION_DENIED', index=94, number=31103,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INPUT_VIDEO_INVALID_ARGUMENT', index=95, number=31104,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INPUT_VIDEO_MODIFY_SUCCESS', index=96, number=31200,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INPUT_VIDEO_MODIFY_PENDING', index=97, number=31201,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INPUT_VIDEO_MODIFY_FAILED', index=98, number=31203,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REQUEST_DISABLED_FOR_MAINTENANCE', index=99, number=39997,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INPUT_WRITES_DISABLED_FOR_MAINTENANCE', index=100, number=39998,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INPUT_INVALID_REQUEST', index=101, number=39999,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PREDICT_INVALID_REQUEST', index=102, number=40001,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEARCH_INVALID_REQUEST', index=103, number=40002,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONCEPTS_INVALID_REQUEST', index=104, number=40003,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATABASE_DUPLICATE_KEY', index=105, number=40010,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATABASE_STATEMENT_TIMEOUT', index=106, number=40011,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATABASE_INVALID_ROWS_AFFECTED', index=107, number=40012,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATABASE_DEADLOCK_DETECTED', index=108, number=40013,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATABASE_FAIL_TASK', index=109, number=40014,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATABASE_FAIL_TO_GET_CONNECTIONS', index=110, number=40015,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATABASE_TOO_MANY_CLIENTS', index=111, number=40016,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATABASE_CONSTRAINT_VIOLATED', index=112, number=40017,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ASYNC_WORKER_MULTI_ERRORS', index=113, number=40020,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RPC_REQUEST_QUEUE_FULL', index=114, number=40030,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RPC_SERVER_UNAVAILABLE', index=115, number=40031,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RPC_REQUEST_TIMEOUT', index=116, number=40032,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RPC_MAX_MESSAGE_SIZE_EXCEEDED', index=117, number=40033,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RPC_CANCELED', index=118, number=40035,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLUSTER_INTERNAL_FAILURE', index=119, number=43040,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXTERNAL_CONNECTION_ERROR', index=120, number=40034,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QUEUE_CONN_ERROR', index=121, number=41000,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QUEUE_CLOSE_REQUEST_TIMEOUT', index=122, number=41002,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QUEUE_CONN_CLOSED', index=123, number=41003,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QUEUE_PUBLISH_ACK_TIMEOUT', index=124, number=41004,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QUEUE_PUBLISH_ERROR', index=125, number=41005,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QUEUE_SUBSCRIPTION_TIMEOUT', index=126, number=41006,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QUEUE_SUBSCRIPTION_ERROR', index=127, number=41007,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QUEUE_MARSHALLING_FAILED', index=128, number=41008,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QUEUE_UNMARSHALLING_FAILED', index=129, number=41009,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QUEUE_MAX_MSG_REDELIVERY_EXCEEDED', index=130, number=41010,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QUEUE_ACK_FAILURE', index=131, number=41011,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SQS_OVERLIMIT', index=132, number=41100,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SQS_INVALID_RECEIPT_HANDLE', index=133, number=41101,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SQS_UNKNOWN', index=134, number=41102,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VISUALIZATION_SUCCESS', index=135, number=42000,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VISUALIZATION_PENDING', index=136, number=42001,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VISUALIZATION_FAILED', index=137, number=42002,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VISUALIZATION_INVALID_REQUEST', index=138, number=42003,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_APP_VISUALIZATION', index=139, number=42004,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VISUALIZATION_TOO_MANY_URLS', index=140, number=42005,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VISUALIZATION_FAILED_TO_SAMPLE_APP', index=141, number=42006,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VISUALIZATION_FAILED_TO_EMBED', index=142, number=42007,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VISUALIZATION_S3_ERROR', index=143, number=42008,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEARCH_INTERNAL_FAILURE', index=144, number=43001,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEARCH_PROJECTION_FAILURE', index=145, number=43002,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEARCH_PREDICTION_FAILURE', index=146, number=43003,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEARCH_BY_NOT_FULLY_INDEXED_INPUT', index=147, number=43004,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STRIPE_EVENT_ERROR', index=148, number=44001,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CACHE_MISS', index=149, number=45001,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REDIS_SCRIPT_EXITED_WITH_FAILURE', index=150, number=45002,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SIGNUP_EVENT_ERROR', index=151, number=46001,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SIGNUP_FLAGGED', index=152, number=46002,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='APP_COUNT_INVALID_MESSAGE', index=153, number=47001,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='APP_COUNT_UPDATE_INCREMENT_FAILED', index=154, number=47002,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='APP_COUNT_REBUILD_FAILED', index=155, number=47003,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='APP_COUNT_INTERNAL_FAILURE', index=156, number=47004,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MP_DOWNLOAD_ERROR', index=157, number=47101,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MP_RESOLVE_DNS_ERROR', index=158, number=47102,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MP_DOWNLOAD_MAX_SIZE_EXCEEDED_ERROR', index=159, number=47103,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MP_IMAGE_DECODE_ERROR', index=160, number=47104,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MP_INVALID_ARGUMENT', index=161, number=47105,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MP_IMAGE_PROCESSING_ERROR', index=162, number=47106,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='USER_CONSERNT_FACE', index=163, number=50001,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WORKER_ACTIVE', index=164, number=51001,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WORKER_INACTIVE', index=165, number=51002,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL_SERVER_ISSUE', index=166, number=98004,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL_FETCHING_ISSUE', index=167, number=98005,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL_DATABASE_ISSUE', index=168, number=98006,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL_UNEXPECTED_TIMEOUT', index=169, number=98009,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL_UNEXPECTED_V1', index=170, number=98010,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL_UNEXPECTED_PANIC', index=171, number=98011,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL_UNEXPECTED_SPIRE', index=172, number=98012,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL_REDIS_UNAVAILABLE', index=173, number=98013,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL_RESOURCE_EXHAUSTED', index=174, number=98014,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL_REDIS_UNCATEGORIZED', index=175, number=98015,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONN_UNCATEGORIZED', index=176, number=99001,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODEL_UNCATEGORIZED', index=177, number=99002,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INPUT_UNCATEGORIZED', index=178, number=99003,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL_UNCATEGORIZED', index=179, number=99009,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_REQUEST', index=180, number=90400,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SERVER_ERROR', index=181, number=90500,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=69,
  serialized_end=5744,
)
_sym_db.RegisterEnumDescriptor(_STATUSCODE)

StatusCode = enum_type_wrapper.EnumTypeWrapper(_STATUSCODE)
ZERO = 0
SUCCESS = 10000
MIXED_STATUS = 10010
FAILURE = 10020
CONN_ACCOUNT_ISSUES = 11000
CONN_TOKEN_INVALID = 11001
CONN_CREDENTIALS_INVALID = 11002
CONN_EXCEED_HOURLY_LIMIT = 11003
CONN_EXCEED_MONTHLY_LIMIT = 11004
CONN_THROTTLED = 11005
CONN_EXCEEDS_LIMITS = 11006
CONN_INSUFFICIENT_SCOPES = 11007
CONN_KEY_INVALID = 11008
CONN_KEY_NOT_FOUND = 11009
CONN_BAD_REQUEST_FORMAT = 11100
CONN_DOES_NOT_EXIST = 11101
CONN_INVALID_REQUEST = 11102
CONN_METHOD_NOT_ALLOWED = 11103
MODEL_TRAINED = 21100
MODEL_TRAINING = 21101
MODEL_UNTRAINED = 21102
MODEL_QUEUED_FOR_TRAINING = 21103
MODEL_TRAINING_NO_DATA = 21110
MODEL_TRAINING_NO_POSITIVES = 21111
MODEL_TRAINING_ONE_VS_N_SINGLE_CLASS = 21112
MODEL_TRAINING_TIMED_OUT = 21113
MODEL_TRAINING_WAITING_ERROR = 21114
MODEL_TRAINING_UNKNOWN_ERROR = 21115
MODEL_TRAINING_MSG_REDELIVER = 21116
MODEL_MODIFY_SUCCESS = 21150
MODEL_MODIFY_PENDING = 21151
MODEL_MODIFY_FAILED = 21152
MODEL_DOES_NOT_EXIST = 21200
MODEL_PERMISSION_DENIED = 21201
MODEL_INVALID_ARGUMENT = 21202
MODEL_INVALID_REQUEST = 21203
MODEL_EVALUATED = 21300
MODEL_EVALUATING = 21301
MODEL_NOT_EVALUATED = 21302
MODEL_QUEUED_FOR_EVALUATION = 21303
MODEL_EVALUATION_TIMED_OUT = 21310
MODEL_EVALUATION_WAITING_ERROR = 21311
MODEL_EVALUATION_UNKNOWN_ERROR = 21312
MODEL_PREDICTION_FAILED = 21313
MODEL_EVALUATION_MSG_REDELIVER = 21314
MODEL_EVALUATION_NEED_LABELS = 21315
MODEL_EVALUATION_NEED_INPUTS = 21316
WORKFLOW_NO_MATCHING_INPUT = 22001
WORKFLOW_REQUIRE_TRAINED_MODEL = 22002
WORKFLOW_DUPLICATE = 22100
WORKFLOW_UNSUPPORTED_FORMAT = 22101
WORKFLOW_DOES_NOT_EXIST = 22102
WORKFLOW_PERMISSION_DENIED = 22103
WORKFLOW_INVALID_ARGUMENT = 22104
WORKFLOW_INVALID_RECIPE = 22105
WORKFLOW_INVALID_TEMPLATE = 22106
WORKFLOW_INVALID_GRAPH = 22107
WORKFLOW_INTERNAL_FAILURE = 22108
WORKFLOW_INVALID_REQUEST = 22999
WORKFLOW_MODIFY_SUCCESS = 22150
WORKFLOW_MODIFY_PENDING = 22151
WORKFLOW_MODIFY_FAILED = 22152
CONCEPT_MODIFY_SUCCESS = 23150
CONCEPT_MODIFY_PENDING = 23151
CONCEPT_MODIFY_FAILED = 23152
ANNOTATION_SUCCESS = 24150
ANNOTATION_PENDING = 24151
ANNOTATION_FAILED = 24152
ANNOTATION_IN_PROGRESS = 24153
INPUT_IMAGE_DOWNLOAD_SUCCESS = 30000
INPUT_IMAGE_DOWNLOAD_PENDING = 30001
INPUT_IMAGE_DOWNLOAD_FAILED = 30002
INPUT_IMAGE_DOWNLOAD_IN_PROGRESS = 30003
INPUT_IMAGE_STATUS_UPDATE_FAILED = 30004
INPUT_IMAGE_DELETE_FAILED = 30005
INPUT_IMAGE_DUPLICATE = 30100
INPUT_IMAGE_UNSUPPORTED_FORMAT = 30101
INPUT_IMAGE_DOES_NOT_EXIST = 30102
INPUT_IMAGE_PERMISSION_DENIED = 30103
INPUT_IMAGE_INVALID_ARGUMENT = 30104
INPUT_IMAGE_MODIFY_SUCCESS = 30200
INPUT_IMAGE_MODIFY_PENDING = 30201
INPUT_IMAGE_MODIFY_FAILED = 30203
ALL_INPUT_IMAGES_INVALID_BYTES = 30300
INPUT_IMAGE_CLUSTER_SUCCESS = 30400
INPUT_IMAGE_CLUSTER_PENDING = 30401
INPUT_IMAGE_CLUSTER_FAILED = 30402
INPUT_IMAGE_CLUSTER_IN_PROGRESS = 30403
INPUT_VIDEO_DOWNLOAD_SUCCESS = 31000
INPUT_VIDEO_DOWNLOAD_PENDING = 31001
INPUT_VIDEO_DOWNLOAD_FAILED = 31002
INPUT_VIDEO_DUPLICATE = 31100
INPUT_VIDEO_UNSUPPORTED_FORMAT = 31101
INPUT_VIDEO_DOES_NOT_EXIST = 31102
INPUT_VIDEO_PERMISSION_DENIED = 31103
INPUT_VIDEO_INVALID_ARGUMENT = 31104
INPUT_VIDEO_MODIFY_SUCCESS = 31200
INPUT_VIDEO_MODIFY_PENDING = 31201
INPUT_VIDEO_MODIFY_FAILED = 31203
REQUEST_DISABLED_FOR_MAINTENANCE = 39997
INPUT_WRITES_DISABLED_FOR_MAINTENANCE = 39998
INPUT_INVALID_REQUEST = 39999
PREDICT_INVALID_REQUEST = 40001
SEARCH_INVALID_REQUEST = 40002
CONCEPTS_INVALID_REQUEST = 40003
DATABASE_DUPLICATE_KEY = 40010
DATABASE_STATEMENT_TIMEOUT = 40011
DATABASE_INVALID_ROWS_AFFECTED = 40012
DATABASE_DEADLOCK_DETECTED = 40013
DATABASE_FAIL_TASK = 40014
DATABASE_FAIL_TO_GET_CONNECTIONS = 40015
DATABASE_TOO_MANY_CLIENTS = 40016
DATABASE_CONSTRAINT_VIOLATED = 40017
ASYNC_WORKER_MULTI_ERRORS = 40020
RPC_REQUEST_QUEUE_FULL = 40030
RPC_SERVER_UNAVAILABLE = 40031
RPC_REQUEST_TIMEOUT = 40032
RPC_MAX_MESSAGE_SIZE_EXCEEDED = 40033
RPC_CANCELED = 40035
CLUSTER_INTERNAL_FAILURE = 43040
EXTERNAL_CONNECTION_ERROR = 40034
QUEUE_CONN_ERROR = 41000
QUEUE_CLOSE_REQUEST_TIMEOUT = 41002
QUEUE_CONN_CLOSED = 41003
QUEUE_PUBLISH_ACK_TIMEOUT = 41004
QUEUE_PUBLISH_ERROR = 41005
QUEUE_SUBSCRIPTION_TIMEOUT = 41006
QUEUE_SUBSCRIPTION_ERROR = 41007
QUEUE_MARSHALLING_FAILED = 41008
QUEUE_UNMARSHALLING_FAILED = 41009
QUEUE_MAX_MSG_REDELIVERY_EXCEEDED = 41010
QUEUE_ACK_FAILURE = 41011
SQS_OVERLIMIT = 41100
SQS_INVALID_RECEIPT_HANDLE = 41101
SQS_UNKNOWN = 41102
VISUALIZATION_SUCCESS = 42000
VISUALIZATION_PENDING = 42001
VISUALIZATION_FAILED = 42002
VISUALIZATION_INVALID_REQUEST = 42003
MISSING_APP_VISUALIZATION = 42004
VISUALIZATION_TOO_MANY_URLS = 42005
VISUALIZATION_FAILED_TO_SAMPLE_APP = 42006
VISUALIZATION_FAILED_TO_EMBED = 42007
VISUALIZATION_S3_ERROR = 42008
SEARCH_INTERNAL_FAILURE = 43001
SEARCH_PROJECTION_FAILURE = 43002
SEARCH_PREDICTION_FAILURE = 43003
SEARCH_BY_NOT_FULLY_INDEXED_INPUT = 43004
STRIPE_EVENT_ERROR = 44001
CACHE_MISS = 45001
REDIS_SCRIPT_EXITED_WITH_FAILURE = 45002
SIGNUP_EVENT_ERROR = 46001
SIGNUP_FLAGGED = 46002
APP_COUNT_INVALID_MESSAGE = 47001
APP_COUNT_UPDATE_INCREMENT_FAILED = 47002
APP_COUNT_REBUILD_FAILED = 47003
APP_COUNT_INTERNAL_FAILURE = 47004
MP_DOWNLOAD_ERROR = 47101
MP_RESOLVE_DNS_ERROR = 47102
MP_DOWNLOAD_MAX_SIZE_EXCEEDED_ERROR = 47103
MP_IMAGE_DECODE_ERROR = 47104
MP_INVALID_ARGUMENT = 47105
MP_IMAGE_PROCESSING_ERROR = 47106
USER_CONSERNT_FACE = 50001
WORKER_ACTIVE = 51001
WORKER_INACTIVE = 51002
INTERNAL_SERVER_ISSUE = 98004
INTERNAL_FETCHING_ISSUE = 98005
INTERNAL_DATABASE_ISSUE = 98006
INTERNAL_UNEXPECTED_TIMEOUT = 98009
INTERNAL_UNEXPECTED_V1 = 98010
INTERNAL_UNEXPECTED_PANIC = 98011
INTERNAL_UNEXPECTED_SPIRE = 98012
INTERNAL_REDIS_UNAVAILABLE = 98013
INTERNAL_RESOURCE_EXHAUSTED = 98014
INTERNAL_REDIS_UNCATEGORIZED = 98015
CONN_UNCATEGORIZED = 99001
MODEL_UNCATEGORIZED = 99002
INPUT_UNCATEGORIZED = 99003
INTERNAL_UNCATEGORIZED = 99009
BAD_REQUEST = 90400
SERVER_ERROR = 90500


DESCRIPTOR.enum_types_by_name['StatusCode'] = _STATUSCODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('Z\006status\242\002\004CAIP\302\002\001_\312\002\030Clarifai\\Internal\\Status'))
# @@protoc_insertion_point(module_scope)
