# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/clarifai/api/data.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from clarifai.rest.grpc.proto.clarifai.api import cluster_pb2 as proto_dot_clarifai_dot_api_dot_cluster__pb2
from clarifai.rest.grpc.proto.clarifai.api import color_pb2 as proto_dot_clarifai_dot_api_dot_color__pb2
from clarifai.rest.grpc.proto.clarifai.api import common_pb2 as proto_dot_clarifai_dot_api_dot_common__pb2
from clarifai.rest.grpc.proto.clarifai.api import concept_pb2 as proto_dot_clarifai_dot_api_dot_concept__pb2
from clarifai.rest.grpc.proto.clarifai.api import embedding_pb2 as proto_dot_clarifai_dot_api_dot_embedding__pb2
from clarifai.rest.grpc.proto.clarifai.api import face_pb2 as proto_dot_clarifai_dot_api_dot_face__pb2
from clarifai.rest.grpc.proto.clarifai.api import focus_pb2 as proto_dot_clarifai_dot_api_dot_focus__pb2
from clarifai.rest.grpc.proto.clarifai.api import geo_pb2 as proto_dot_clarifai_dot_api_dot_geo__pb2
from clarifai.rest.grpc.proto.clarifai.api import image_pb2 as proto_dot_clarifai_dot_api_dot_image__pb2
from clarifai.rest.grpc.proto.clarifai.api import video_pb2 as proto_dot_clarifai_dot_api_dot_video__pb2
from clarifai.rest.grpc.proto.clarifai.api.utils import extensions_pb2 as proto_dot_clarifai_dot_api_dot_utils_dot_extensions__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/clarifai/api/data.proto',
  package='clarifai.api',
  syntax='proto3',
  serialized_pb=_b('\n\x1dproto/clarifai/api/data.proto\x12\x0c\x63larifai.api\x1a proto/clarifai/api/cluster.proto\x1a\x1eproto/clarifai/api/color.proto\x1a\x1fproto/clarifai/api/common.proto\x1a proto/clarifai/api/concept.proto\x1a\"proto/clarifai/api/embedding.proto\x1a\x1dproto/clarifai/api/face.proto\x1a\x1eproto/clarifai/api/focus.proto\x1a\x1cproto/clarifai/api/geo.proto\x1a\x1eproto/clarifai/api/image.proto\x1a\x1eproto/clarifai/api/video.proto\x1a)proto/clarifai/api/utils/extensions.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xcf\x03\n\x04\x44\x61ta\x12\"\n\x05image\x18\x01 \x01(\x0b\x32\x13.clarifai.api.Image\x12\"\n\x05video\x18\x02 \x01(\x0b\x32\x13.clarifai.api.Video\x12\'\n\x08\x63oncepts\x18\x03 \x03(\x0b\x32\x15.clarifai.api.Concept\x12 \n\x04\x66\x61\x63\x65\x18\x04 \x01(\x0b\x32\x12.clarifai.api.Face\x12)\n\x08metadata\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x1e\n\x03geo\x18\x06 \x01(\x0b\x32\x11.clarifai.api.Geo\x12#\n\x06\x63olors\x18\x07 \x03(\x0b\x32\x13.clarifai.api.Color\x12\'\n\x08\x63lusters\x18\x08 \x03(\x0b\x32\x15.clarifai.api.Cluster\x12+\n\nembeddings\x18\t \x03(\x0b\x32\x17.clarifai.api.Embedding\x12\"\n\x05\x66ocus\x18\n \x01(\x0b\x32\x13.clarifai.api.Focus\x12%\n\x07regions\x18\x0b \x03(\x0b\x32\x14.clarifai.api.Region\x12#\n\x06\x66rames\x18\x0c \x03(\x0b\x32\x13.clarifai.api.Frame\"e\n\x06Region\x12\n\n\x02id\x18\x01 \x01(\t\x12-\n\x0bregion_info\x18\x02 \x01(\x0b\x32\x18.clarifai.api.RegionInfo\x12 \n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x12.clarifai.api.Data\"\xa2\x01\n\nRegionInfo\x12/\n\x0c\x62ounding_box\x18\x01 \x01(\x0b\x32\x19.clarifai.api.BoundingBox\x12\r\n\x05value\x18\x02 \x01(\x02\x12\x32\n\x08\x66\x65\x65\x64\x62\x61\x63k\x18\x03 \x01(\x0e\x32 .clarifai.api.RegionInfoFeedback\x12 \n\x04mask\x18\x04 \x01(\x0b\x32\x12.clarifai.api.Mask\"o\n\x0b\x42oundingBox\x12\x15\n\x07top_row\x18\x01 \x01(\x02\x42\x04\x80\xb5\x18\x01\x12\x16\n\x08left_col\x18\x02 \x01(\x02\x42\x04\x80\xb5\x18\x01\x12\x18\n\nbottom_row\x18\x03 \x01(\x02\x42\x04\x80\xb5\x18\x01\x12\x17\n\tright_col\x18\x04 \x01(\x02\x42\x04\x80\xb5\x18\x01\"4\n\tFrameInfo\x12\x13\n\x05index\x18\x01 \x01(\rB\x04\x80\xb5\x18\x01\x12\x12\n\x04time\x18\x02 \x01(\rB\x04\x80\xb5\x18\x01\"V\n\x05\x46rame\x12+\n\nframe_info\x18\x01 \x01(\x0b\x32\x17.clarifai.api.FrameInfo\x12 \n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x12.clarifai.api.Data\"N\n\x04Mask\x12\"\n\x05\x63olor\x18\x01 \x01(\x0b\x32\x13.clarifai.api.Color\x12\"\n\x05image\x18\x02 \x01(\x0b\x32\x13.clarifai.api.Image*W\n\x12RegionInfoFeedback\x12\x0c\n\x08\x61\x63\x63urate\x10\x00\x12\r\n\tmisplaced\x10\x01\x12\x10\n\x0cnot_detected\x10\x02\x12\x12\n\x0e\x66\x61lse_positive\x10\x03\x42$Z\x03\x61pi\xa2\x02\x04\x43\x41IP\xc2\x02\x01_\xca\x02\x11\x43larifai\\Internalb\x06proto3')
  ,
  dependencies=[proto_dot_clarifai_dot_api_dot_cluster__pb2.DESCRIPTOR,proto_dot_clarifai_dot_api_dot_color__pb2.DESCRIPTOR,proto_dot_clarifai_dot_api_dot_common__pb2.DESCRIPTOR,proto_dot_clarifai_dot_api_dot_concept__pb2.DESCRIPTOR,proto_dot_clarifai_dot_api_dot_embedding__pb2.DESCRIPTOR,proto_dot_clarifai_dot_api_dot_face__pb2.DESCRIPTOR,proto_dot_clarifai_dot_api_dot_focus__pb2.DESCRIPTOR,proto_dot_clarifai_dot_api_dot_geo__pb2.DESCRIPTOR,proto_dot_clarifai_dot_api_dot_image__pb2.DESCRIPTOR,proto_dot_clarifai_dot_api_dot_video__pb2.DESCRIPTOR,proto_dot_clarifai_dot_api_dot_utils_dot_extensions__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,])

_REGIONINFOFEEDBACK = _descriptor.EnumDescriptor(
  name='RegionInfoFeedback',
  full_name='clarifai.api.RegionInfoFeedback',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='accurate', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='misplaced', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='not_detected', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='false_positive', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1515,
  serialized_end=1602,
)
_sym_db.RegisterEnumDescriptor(_REGIONINFOFEEDBACK)

RegionInfoFeedback = enum_type_wrapper.EnumTypeWrapper(_REGIONINFOFEEDBACK)
accurate = 0
misplaced = 1
not_detected = 2
false_positive = 3



_DATA = _descriptor.Descriptor(
  name='Data',
  full_name='clarifai.api.Data',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='image', full_name='clarifai.api.Data.image', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='video', full_name='clarifai.api.Data.video', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='concepts', full_name='clarifai.api.Data.concepts', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='face', full_name='clarifai.api.Data.face', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='clarifai.api.Data.metadata', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geo', full_name='clarifai.api.Data.geo', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='colors', full_name='clarifai.api.Data.colors', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clusters', full_name='clarifai.api.Data.clusters', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='embeddings', full_name='clarifai.api.Data.embeddings', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='focus', full_name='clarifai.api.Data.focus', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='regions', full_name='clarifai.api.Data.regions', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frames', full_name='clarifai.api.Data.frames', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=447,
  serialized_end=910,
)


_REGION = _descriptor.Descriptor(
  name='Region',
  full_name='clarifai.api.Region',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='clarifai.api.Region.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='region_info', full_name='clarifai.api.Region.region_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='clarifai.api.Region.data', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=912,
  serialized_end=1013,
)


_REGIONINFO = _descriptor.Descriptor(
  name='RegionInfo',
  full_name='clarifai.api.RegionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='bounding_box', full_name='clarifai.api.RegionInfo.bounding_box', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='clarifai.api.RegionInfo.value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feedback', full_name='clarifai.api.RegionInfo.feedback', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mask', full_name='clarifai.api.RegionInfo.mask', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1016,
  serialized_end=1178,
)


_BOUNDINGBOX = _descriptor.Descriptor(
  name='BoundingBox',
  full_name='clarifai.api.BoundingBox',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='top_row', full_name='clarifai.api.BoundingBox.top_row', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\265\030\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='left_col', full_name='clarifai.api.BoundingBox.left_col', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\265\030\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bottom_row', full_name='clarifai.api.BoundingBox.bottom_row', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\265\030\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='right_col', full_name='clarifai.api.BoundingBox.right_col', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\265\030\001')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1180,
  serialized_end=1291,
)


_FRAMEINFO = _descriptor.Descriptor(
  name='FrameInfo',
  full_name='clarifai.api.FrameInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='clarifai.api.FrameInfo.index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\265\030\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time', full_name='clarifai.api.FrameInfo.time', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\265\030\001')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1293,
  serialized_end=1345,
)


_FRAME = _descriptor.Descriptor(
  name='Frame',
  full_name='clarifai.api.Frame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='frame_info', full_name='clarifai.api.Frame.frame_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='clarifai.api.Frame.data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1347,
  serialized_end=1433,
)


_MASK = _descriptor.Descriptor(
  name='Mask',
  full_name='clarifai.api.Mask',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='color', full_name='clarifai.api.Mask.color', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image', full_name='clarifai.api.Mask.image', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1435,
  serialized_end=1513,
)

_DATA.fields_by_name['image'].message_type = proto_dot_clarifai_dot_api_dot_image__pb2._IMAGE
_DATA.fields_by_name['video'].message_type = proto_dot_clarifai_dot_api_dot_video__pb2._VIDEO
_DATA.fields_by_name['concepts'].message_type = proto_dot_clarifai_dot_api_dot_concept__pb2._CONCEPT
_DATA.fields_by_name['face'].message_type = proto_dot_clarifai_dot_api_dot_face__pb2._FACE
_DATA.fields_by_name['metadata'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_DATA.fields_by_name['geo'].message_type = proto_dot_clarifai_dot_api_dot_geo__pb2._GEO
_DATA.fields_by_name['colors'].message_type = proto_dot_clarifai_dot_api_dot_color__pb2._COLOR
_DATA.fields_by_name['clusters'].message_type = proto_dot_clarifai_dot_api_dot_cluster__pb2._CLUSTER
_DATA.fields_by_name['embeddings'].message_type = proto_dot_clarifai_dot_api_dot_embedding__pb2._EMBEDDING
_DATA.fields_by_name['focus'].message_type = proto_dot_clarifai_dot_api_dot_focus__pb2._FOCUS
_DATA.fields_by_name['regions'].message_type = _REGION
_DATA.fields_by_name['frames'].message_type = _FRAME
_REGION.fields_by_name['region_info'].message_type = _REGIONINFO
_REGION.fields_by_name['data'].message_type = _DATA
_REGIONINFO.fields_by_name['bounding_box'].message_type = _BOUNDINGBOX
_REGIONINFO.fields_by_name['feedback'].enum_type = _REGIONINFOFEEDBACK
_REGIONINFO.fields_by_name['mask'].message_type = _MASK
_FRAME.fields_by_name['frame_info'].message_type = _FRAMEINFO
_FRAME.fields_by_name['data'].message_type = _DATA
_MASK.fields_by_name['color'].message_type = proto_dot_clarifai_dot_api_dot_color__pb2._COLOR
_MASK.fields_by_name['image'].message_type = proto_dot_clarifai_dot_api_dot_image__pb2._IMAGE
DESCRIPTOR.message_types_by_name['Data'] = _DATA
DESCRIPTOR.message_types_by_name['Region'] = _REGION
DESCRIPTOR.message_types_by_name['RegionInfo'] = _REGIONINFO
DESCRIPTOR.message_types_by_name['BoundingBox'] = _BOUNDINGBOX
DESCRIPTOR.message_types_by_name['FrameInfo'] = _FRAMEINFO
DESCRIPTOR.message_types_by_name['Frame'] = _FRAME
DESCRIPTOR.message_types_by_name['Mask'] = _MASK
DESCRIPTOR.enum_types_by_name['RegionInfoFeedback'] = _REGIONINFOFEEDBACK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Data = _reflection.GeneratedProtocolMessageType('Data', (_message.Message,), dict(
  DESCRIPTOR = _DATA,
  __module__ = 'proto.clarifai.api.data_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.Data)
  ))
_sym_db.RegisterMessage(Data)

Region = _reflection.GeneratedProtocolMessageType('Region', (_message.Message,), dict(
  DESCRIPTOR = _REGION,
  __module__ = 'proto.clarifai.api.data_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.Region)
  ))
_sym_db.RegisterMessage(Region)

RegionInfo = _reflection.GeneratedProtocolMessageType('RegionInfo', (_message.Message,), dict(
  DESCRIPTOR = _REGIONINFO,
  __module__ = 'proto.clarifai.api.data_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.RegionInfo)
  ))
_sym_db.RegisterMessage(RegionInfo)

BoundingBox = _reflection.GeneratedProtocolMessageType('BoundingBox', (_message.Message,), dict(
  DESCRIPTOR = _BOUNDINGBOX,
  __module__ = 'proto.clarifai.api.data_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.BoundingBox)
  ))
_sym_db.RegisterMessage(BoundingBox)

FrameInfo = _reflection.GeneratedProtocolMessageType('FrameInfo', (_message.Message,), dict(
  DESCRIPTOR = _FRAMEINFO,
  __module__ = 'proto.clarifai.api.data_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.FrameInfo)
  ))
_sym_db.RegisterMessage(FrameInfo)

Frame = _reflection.GeneratedProtocolMessageType('Frame', (_message.Message,), dict(
  DESCRIPTOR = _FRAME,
  __module__ = 'proto.clarifai.api.data_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.Frame)
  ))
_sym_db.RegisterMessage(Frame)

Mask = _reflection.GeneratedProtocolMessageType('Mask', (_message.Message,), dict(
  DESCRIPTOR = _MASK,
  __module__ = 'proto.clarifai.api.data_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.Mask)
  ))
_sym_db.RegisterMessage(Mask)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('Z\003api\242\002\004CAIP\302\002\001_\312\002\021Clarifai\\Internal'))
_BOUNDINGBOX.fields_by_name['top_row'].has_options = True
_BOUNDINGBOX.fields_by_name['top_row']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\265\030\001'))
_BOUNDINGBOX.fields_by_name['left_col'].has_options = True
_BOUNDINGBOX.fields_by_name['left_col']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\265\030\001'))
_BOUNDINGBOX.fields_by_name['bottom_row'].has_options = True
_BOUNDINGBOX.fields_by_name['bottom_row']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\265\030\001'))
_BOUNDINGBOX.fields_by_name['right_col'].has_options = True
_BOUNDINGBOX.fields_by_name['right_col']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\265\030\001'))
_FRAMEINFO.fields_by_name['index'].has_options = True
_FRAMEINFO.fields_by_name['index']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\265\030\001'))
_FRAMEINFO.fields_by_name['time'].has_options = True
_FRAMEINFO.fields_by_name['time']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\265\030\001'))
# @@protoc_insertion_point(module_scope)
