# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/clarifai/api/model_version.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from clarifai.rest.grpc.proto.clarifai.api import common_pb2 as proto_dot_clarifai_dot_api_dot_common__pb2
from clarifai.rest.grpc.proto.clarifai.api import concept_pb2 as proto_dot_clarifai_dot_api_dot_concept__pb2
from clarifai.rest.grpc.proto.clarifai.api.status import status_pb2 as proto_dot_clarifai_dot_api_dot_status_dot_status__pb2
from clarifai.rest.grpc.proto.clarifai.api.utils import extensions_pb2 as proto_dot_clarifai_dot_api_dot_utils_dot_extensions__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/clarifai/api/model_version.proto',
  package='clarifai.api',
  syntax='proto3',
  serialized_pb=_b('\n&proto/clarifai/api/model_version.proto\x12\x0c\x63larifai.api\x1a\x1fproto/clarifai/api/common.proto\x1a proto/clarifai/api/concept.proto\x1a&proto/clarifai/api/status/status.proto\x1a)proto/clarifai/api/utils/extensions.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa2\x02\n\x0cModelVersion\x12\n\n\x02id\x18\x01 \x01(\t\x12.\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x06status\x18\x03 \x01(\x0b\x32\x1b.clarifai.api.status.Status\x12\x1c\n\x14\x61\x63tive_concept_count\x18\x04 \x01(\r\x12*\n\x07metrics\x18\x05 \x01(\x0b\x32\x19.clarifai.api.EvalMetrics\x12\x19\n\x11total_input_count\x18\x06 \x01(\r\x12\x44\n\x17pretrained_model_config\x18\x07 \x01(\x0b\x32#.clarifai.api.PretrainedModelConfig\"1\n\x15PretrainedModelConfig\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\"o\n\x16GetModelVersionRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12\x10\n\x08model_id\x18\x02 \x01(\t\x12\x12\n\nversion_id\x18\x03 \x01(\t\"\x92\x01\n\x18ListModelVersionsRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12\x10\n\x08model_id\x18\x02 \x01(\t\x12\x0c\n\x04page\x18\x03 \x01(\r\x12\x10\n\x08per_page\x18\x04 \x01(\r\x12\x13\n\x0b\x63oncept_ids\x18\x05 \x03(\t\"\x91\x01\n\x18PostModelVersionsRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12\x10\n\x08model_id\x18\x02 \x01(\t\x12\x32\n\x0emodel_versions\x18\x03 \x03(\x0b\x32\x1a.clarifai.api.ModelVersion\"r\n\x19\x44\x65leteModelVersionRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12\x10\n\x08model_id\x18\x03 \x01(\t\x12\x12\n\nversion_id\x18\x04 \x01(\t\"|\n\x1aSingleModelVersionResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.clarifai.api.status.Status\x12\x31\n\rmodel_version\x18\x02 \x01(\x0b\x32\x1a.clarifai.api.ModelVersion\"\x82\x01\n\x19MultiModelVersionResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.clarifai.api.status.Status\x12\x38\n\x0emodel_versions\x18\x02 \x03(\x0b\x32\x1a.clarifai.api.ModelVersionB\x04\x80\xb5\x18\x01\"1\n\nLabelCount\x12\x14\n\x0c\x63oncept_name\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\r\"L\n\x11LabelDistribution\x12\x37\n\x15positive_label_counts\x18\x01 \x03(\x0b\x32\x18.clarifai.api.LabelCount\"B\n\x17\x43ooccurrenceMatrixEntry\x12\x0b\n\x03row\x18\x01 \x01(\t\x12\x0b\n\x03\x63ol\x18\x02 \x01(\t\x12\r\n\x05\x63ount\x18\x03 \x01(\r\"`\n\x12\x43ooccurrenceMatrix\x12\x35\n\x06matrix\x18\x01 \x03(\x0b\x32%.clarifai.api.CooccurrenceMatrixEntry\x12\x13\n\x0b\x63oncept_ids\x18\x02 \x03(\t\"H\n\x14\x43onfusionMatrixEntry\x12\x11\n\tpredicted\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x63tual\x18\x02 \x01(\t\x12\r\n\x05value\x18\x04 \x01(\x02\"Z\n\x0f\x43onfusionMatrix\x12\x32\n\x06matrix\x18\x01 \x03(\x0b\x32\".clarifai.api.ConfusionMatrixEntry\x12\x13\n\x0b\x63oncept_ids\x18\x02 \x03(\t\"3\n\x03ROC\x12\x0b\n\x03\x66pr\x18\x01 \x03(\x02\x12\x0b\n\x03tpr\x18\x02 \x03(\x02\x12\x12\n\nthresholds\x18\x03 \x03(\x02\"M\n\x14PrecisionRecallCurve\x12\x0e\n\x06recall\x18\x01 \x03(\x02\x12\x11\n\tprecision\x18\x02 \x03(\x02\x12\x12\n\nthresholds\x18\x03 \x03(\x02\"\xf1\x01\n\rBinaryMetrics\x12\x0f\n\x07num_pos\x18\x01 \x01(\r\x12\x0f\n\x07num_neg\x18\x02 \x01(\r\x12\x0f\n\x07num_tot\x18\x03 \x01(\r\x12\x0f\n\x07roc_auc\x18\x04 \x01(\x02\x12\n\n\x02\x66\x31\x18\x05 \x01(\x02\x12&\n\x07\x63oncept\x18\x06 \x01(\x0b\x32\x15.clarifai.api.Concept\x12$\n\troc_curve\x18\x07 \x01(\x0b\x32\x11.clarifai.api.ROC\x12\x42\n\x16precision_recall_curve\x18\x08 \x01(\x0b\x32\".clarifai.api.PrecisionRecallCurve\"\x94\x01\n\x10\x45valTestSetEntry\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x31\n\x12predicted_concepts\x18\x03 \x03(\x0b\x32\x15.clarifai.api.Concept\x12\x34\n\x15ground_truth_concepts\x18\x04 \x03(\x0b\x32\x15.clarifai.api.Concept\"\xeb\x01\n\x0eMetricsSummary\x12\x19\n\rtop1_accuracy\x18\x01 \x01(\x02\x42\x02\x18\x01\x12\x19\n\rtop5_accuracy\x18\x02 \x01(\x02\x42\x02\x18\x01\x12\x19\n\x11macro_avg_roc_auc\x18\x03 \x01(\x02\x12\x19\n\x11macro_std_roc_auc\x18\x04 \x01(\x02\x12\x1a\n\x12macro_avg_f1_score\x18\x05 \x01(\x02\x12\x1a\n\x12macro_std_f1_score\x18\x06 \x01(\x02\x12\x1b\n\x13macro_avg_precision\x18\x07 \x01(\x02\x12\x18\n\x10macro_avg_recall\x18\x08 \x01(\x02\"\xff\x02\n\x0b\x45valMetrics\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.clarifai.api.status.Status\x12-\n\x07summary\x18\x02 \x01(\x0b\x32\x1c.clarifai.api.MetricsSummary\x12\x37\n\x10\x63onfusion_matrix\x18\x03 \x01(\x0b\x32\x1d.clarifai.api.ConfusionMatrix\x12=\n\x13\x63ooccurrence_matrix\x18\x04 \x01(\x0b\x32 .clarifai.api.CooccurrenceMatrix\x12\x35\n\x0clabel_counts\x18\x05 \x01(\x0b\x32\x1f.clarifai.api.LabelDistribution\x12\x33\n\x0e\x62inary_metrics\x18\x06 \x03(\x0b\x32\x1b.clarifai.api.BinaryMetrics\x12\x30\n\x08test_set\x18\x07 \x03(\x0b\x32\x1e.clarifai.api.EvalTestSetEntry\"\xc6\x02\n\x1dGetModelVersionMetricsRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12\x10\n\x08model_id\x18\x02 \x01(\t\x12\x12\n\nversion_id\x18\x03 \x01(\t\x12G\n\x06\x66ields\x18\x04 \x01(\x0b\x32\x37.clarifai.api.GetModelVersionMetricsRequest.FieldsValue\x1a\x84\x01\n\x0b\x46ieldsValue\x12\x18\n\x10\x63onfusion_matrix\x18\x01 \x01(\x08\x12\x1b\n\x13\x63ooccurrence_matrix\x18\x02 \x01(\x08\x12\x14\n\x0clabel_counts\x18\x03 \x01(\x08\x12\x16\n\x0e\x62inary_metrics\x18\x04 \x01(\x08\x12\x10\n\x08test_set\x18\x05 \x01(\x08\"\x8d\x01\n\x1ePostModelVersionMetricsRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12\x10\n\x08model_id\x18\x02 \x01(\t\x12\x12\n\nversion_id\x18\x03 \x01(\t\x12\x14\n\x0cmax_examples\x18\x04 \x01(\rB$Z\x03\x61pi\xa2\x02\x04\x43\x41IP\xc2\x02\x01_\xca\x02\x11\x43larifai\\Internalb\x06proto3')
  ,
  dependencies=[proto_dot_clarifai_dot_api_dot_common__pb2.DESCRIPTOR,proto_dot_clarifai_dot_api_dot_concept__pb2.DESCRIPTOR,proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.DESCRIPTOR,proto_dot_clarifai_dot_api_dot_utils_dot_extensions__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_MODELVERSION = _descriptor.Descriptor(
  name='ModelVersion',
  full_name='clarifai.api.ModelVersion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='clarifai.api.ModelVersion.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='clarifai.api.ModelVersion.created_at', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='clarifai.api.ModelVersion.status', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='active_concept_count', full_name='clarifai.api.ModelVersion.active_concept_count', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metrics', full_name='clarifai.api.ModelVersion.metrics', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_input_count', full_name='clarifai.api.ModelVersion.total_input_count', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pretrained_model_config', full_name='clarifai.api.ModelVersion.pretrained_model_config', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=240,
  serialized_end=530,
)


_PRETRAINEDMODELCONFIG = _descriptor.Descriptor(
  name='PretrainedModelConfig',
  full_name='clarifai.api.PretrainedModelConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='clarifai.api.PretrainedModelConfig.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='clarifai.api.PretrainedModelConfig.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=532,
  serialized_end=581,
)


_GETMODELVERSIONREQUEST = _descriptor.Descriptor(
  name='GetModelVersionRequest',
  full_name='clarifai.api.GetModelVersionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.GetModelVersionRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_id', full_name='clarifai.api.GetModelVersionRequest.model_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version_id', full_name='clarifai.api.GetModelVersionRequest.version_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=583,
  serialized_end=694,
)


_LISTMODELVERSIONSREQUEST = _descriptor.Descriptor(
  name='ListModelVersionsRequest',
  full_name='clarifai.api.ListModelVersionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.ListModelVersionsRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_id', full_name='clarifai.api.ListModelVersionsRequest.model_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page', full_name='clarifai.api.ListModelVersionsRequest.page', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='per_page', full_name='clarifai.api.ListModelVersionsRequest.per_page', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='concept_ids', full_name='clarifai.api.ListModelVersionsRequest.concept_ids', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=697,
  serialized_end=843,
)


_POSTMODELVERSIONSREQUEST = _descriptor.Descriptor(
  name='PostModelVersionsRequest',
  full_name='clarifai.api.PostModelVersionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.PostModelVersionsRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_id', full_name='clarifai.api.PostModelVersionsRequest.model_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_versions', full_name='clarifai.api.PostModelVersionsRequest.model_versions', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=846,
  serialized_end=991,
)


_DELETEMODELVERSIONREQUEST = _descriptor.Descriptor(
  name='DeleteModelVersionRequest',
  full_name='clarifai.api.DeleteModelVersionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.DeleteModelVersionRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_id', full_name='clarifai.api.DeleteModelVersionRequest.model_id', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version_id', full_name='clarifai.api.DeleteModelVersionRequest.version_id', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=993,
  serialized_end=1107,
)


_SINGLEMODELVERSIONRESPONSE = _descriptor.Descriptor(
  name='SingleModelVersionResponse',
  full_name='clarifai.api.SingleModelVersionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='clarifai.api.SingleModelVersionResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_version', full_name='clarifai.api.SingleModelVersionResponse.model_version', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1109,
  serialized_end=1233,
)


_MULTIMODELVERSIONRESPONSE = _descriptor.Descriptor(
  name='MultiModelVersionResponse',
  full_name='clarifai.api.MultiModelVersionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='clarifai.api.MultiModelVersionResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_versions', full_name='clarifai.api.MultiModelVersionResponse.model_versions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\265\030\001')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1236,
  serialized_end=1366,
)


_LABELCOUNT = _descriptor.Descriptor(
  name='LabelCount',
  full_name='clarifai.api.LabelCount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='concept_name', full_name='clarifai.api.LabelCount.concept_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='clarifai.api.LabelCount.count', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1368,
  serialized_end=1417,
)


_LABELDISTRIBUTION = _descriptor.Descriptor(
  name='LabelDistribution',
  full_name='clarifai.api.LabelDistribution',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='positive_label_counts', full_name='clarifai.api.LabelDistribution.positive_label_counts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1419,
  serialized_end=1495,
)


_COOCCURRENCEMATRIXENTRY = _descriptor.Descriptor(
  name='CooccurrenceMatrixEntry',
  full_name='clarifai.api.CooccurrenceMatrixEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='row', full_name='clarifai.api.CooccurrenceMatrixEntry.row', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='col', full_name='clarifai.api.CooccurrenceMatrixEntry.col', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='clarifai.api.CooccurrenceMatrixEntry.count', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1497,
  serialized_end=1563,
)


_COOCCURRENCEMATRIX = _descriptor.Descriptor(
  name='CooccurrenceMatrix',
  full_name='clarifai.api.CooccurrenceMatrix',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='matrix', full_name='clarifai.api.CooccurrenceMatrix.matrix', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='concept_ids', full_name='clarifai.api.CooccurrenceMatrix.concept_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1565,
  serialized_end=1661,
)


_CONFUSIONMATRIXENTRY = _descriptor.Descriptor(
  name='ConfusionMatrixEntry',
  full_name='clarifai.api.ConfusionMatrixEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='predicted', full_name='clarifai.api.ConfusionMatrixEntry.predicted', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='actual', full_name='clarifai.api.ConfusionMatrixEntry.actual', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='clarifai.api.ConfusionMatrixEntry.value', index=2,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1663,
  serialized_end=1735,
)


_CONFUSIONMATRIX = _descriptor.Descriptor(
  name='ConfusionMatrix',
  full_name='clarifai.api.ConfusionMatrix',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='matrix', full_name='clarifai.api.ConfusionMatrix.matrix', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='concept_ids', full_name='clarifai.api.ConfusionMatrix.concept_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1737,
  serialized_end=1827,
)


_ROC = _descriptor.Descriptor(
  name='ROC',
  full_name='clarifai.api.ROC',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fpr', full_name='clarifai.api.ROC.fpr', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tpr', full_name='clarifai.api.ROC.tpr', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thresholds', full_name='clarifai.api.ROC.thresholds', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1829,
  serialized_end=1880,
)


_PRECISIONRECALLCURVE = _descriptor.Descriptor(
  name='PrecisionRecallCurve',
  full_name='clarifai.api.PrecisionRecallCurve',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='recall', full_name='clarifai.api.PrecisionRecallCurve.recall', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='precision', full_name='clarifai.api.PrecisionRecallCurve.precision', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thresholds', full_name='clarifai.api.PrecisionRecallCurve.thresholds', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1882,
  serialized_end=1959,
)


_BINARYMETRICS = _descriptor.Descriptor(
  name='BinaryMetrics',
  full_name='clarifai.api.BinaryMetrics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='num_pos', full_name='clarifai.api.BinaryMetrics.num_pos', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_neg', full_name='clarifai.api.BinaryMetrics.num_neg', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_tot', full_name='clarifai.api.BinaryMetrics.num_tot', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='roc_auc', full_name='clarifai.api.BinaryMetrics.roc_auc', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='f1', full_name='clarifai.api.BinaryMetrics.f1', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='concept', full_name='clarifai.api.BinaryMetrics.concept', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='roc_curve', full_name='clarifai.api.BinaryMetrics.roc_curve', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='precision_recall_curve', full_name='clarifai.api.BinaryMetrics.precision_recall_curve', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1962,
  serialized_end=2203,
)


_EVALTESTSETENTRY = _descriptor.Descriptor(
  name='EvalTestSetEntry',
  full_name='clarifai.api.EvalTestSetEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='clarifai.api.EvalTestSetEntry.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url', full_name='clarifai.api.EvalTestSetEntry.url', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='predicted_concepts', full_name='clarifai.api.EvalTestSetEntry.predicted_concepts', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ground_truth_concepts', full_name='clarifai.api.EvalTestSetEntry.ground_truth_concepts', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2206,
  serialized_end=2354,
)


_METRICSSUMMARY = _descriptor.Descriptor(
  name='MetricsSummary',
  full_name='clarifai.api.MetricsSummary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='top1_accuracy', full_name='clarifai.api.MetricsSummary.top1_accuracy', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='top5_accuracy', full_name='clarifai.api.MetricsSummary.top5_accuracy', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='macro_avg_roc_auc', full_name='clarifai.api.MetricsSummary.macro_avg_roc_auc', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='macro_std_roc_auc', full_name='clarifai.api.MetricsSummary.macro_std_roc_auc', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='macro_avg_f1_score', full_name='clarifai.api.MetricsSummary.macro_avg_f1_score', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='macro_std_f1_score', full_name='clarifai.api.MetricsSummary.macro_std_f1_score', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='macro_avg_precision', full_name='clarifai.api.MetricsSummary.macro_avg_precision', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='macro_avg_recall', full_name='clarifai.api.MetricsSummary.macro_avg_recall', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2357,
  serialized_end=2592,
)


_EVALMETRICS = _descriptor.Descriptor(
  name='EvalMetrics',
  full_name='clarifai.api.EvalMetrics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='clarifai.api.EvalMetrics.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='summary', full_name='clarifai.api.EvalMetrics.summary', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='confusion_matrix', full_name='clarifai.api.EvalMetrics.confusion_matrix', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cooccurrence_matrix', full_name='clarifai.api.EvalMetrics.cooccurrence_matrix', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_counts', full_name='clarifai.api.EvalMetrics.label_counts', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='binary_metrics', full_name='clarifai.api.EvalMetrics.binary_metrics', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='test_set', full_name='clarifai.api.EvalMetrics.test_set', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2595,
  serialized_end=2978,
)


_GETMODELVERSIONMETRICSREQUEST_FIELDSVALUE = _descriptor.Descriptor(
  name='FieldsValue',
  full_name='clarifai.api.GetModelVersionMetricsRequest.FieldsValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='confusion_matrix', full_name='clarifai.api.GetModelVersionMetricsRequest.FieldsValue.confusion_matrix', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cooccurrence_matrix', full_name='clarifai.api.GetModelVersionMetricsRequest.FieldsValue.cooccurrence_matrix', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_counts', full_name='clarifai.api.GetModelVersionMetricsRequest.FieldsValue.label_counts', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='binary_metrics', full_name='clarifai.api.GetModelVersionMetricsRequest.FieldsValue.binary_metrics', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='test_set', full_name='clarifai.api.GetModelVersionMetricsRequest.FieldsValue.test_set', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3175,
  serialized_end=3307,
)

_GETMODELVERSIONMETRICSREQUEST = _descriptor.Descriptor(
  name='GetModelVersionMetricsRequest',
  full_name='clarifai.api.GetModelVersionMetricsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.GetModelVersionMetricsRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_id', full_name='clarifai.api.GetModelVersionMetricsRequest.model_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version_id', full_name='clarifai.api.GetModelVersionMetricsRequest.version_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fields', full_name='clarifai.api.GetModelVersionMetricsRequest.fields', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_GETMODELVERSIONMETRICSREQUEST_FIELDSVALUE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2981,
  serialized_end=3307,
)


_POSTMODELVERSIONMETRICSREQUEST = _descriptor.Descriptor(
  name='PostModelVersionMetricsRequest',
  full_name='clarifai.api.PostModelVersionMetricsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.PostModelVersionMetricsRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_id', full_name='clarifai.api.PostModelVersionMetricsRequest.model_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version_id', full_name='clarifai.api.PostModelVersionMetricsRequest.version_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_examples', full_name='clarifai.api.PostModelVersionMetricsRequest.max_examples', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3310,
  serialized_end=3451,
)

_MODELVERSION.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_MODELVERSION.fields_by_name['status'].message_type = proto_dot_clarifai_dot_api_dot_status_dot_status__pb2._STATUS
_MODELVERSION.fields_by_name['metrics'].message_type = _EVALMETRICS
_MODELVERSION.fields_by_name['pretrained_model_config'].message_type = _PRETRAINEDMODELCONFIG
_GETMODELVERSIONREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_LISTMODELVERSIONSREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_POSTMODELVERSIONSREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_POSTMODELVERSIONSREQUEST.fields_by_name['model_versions'].message_type = _MODELVERSION
_DELETEMODELVERSIONREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_SINGLEMODELVERSIONRESPONSE.fields_by_name['status'].message_type = proto_dot_clarifai_dot_api_dot_status_dot_status__pb2._STATUS
_SINGLEMODELVERSIONRESPONSE.fields_by_name['model_version'].message_type = _MODELVERSION
_MULTIMODELVERSIONRESPONSE.fields_by_name['status'].message_type = proto_dot_clarifai_dot_api_dot_status_dot_status__pb2._STATUS
_MULTIMODELVERSIONRESPONSE.fields_by_name['model_versions'].message_type = _MODELVERSION
_LABELDISTRIBUTION.fields_by_name['positive_label_counts'].message_type = _LABELCOUNT
_COOCCURRENCEMATRIX.fields_by_name['matrix'].message_type = _COOCCURRENCEMATRIXENTRY
_CONFUSIONMATRIX.fields_by_name['matrix'].message_type = _CONFUSIONMATRIXENTRY
_BINARYMETRICS.fields_by_name['concept'].message_type = proto_dot_clarifai_dot_api_dot_concept__pb2._CONCEPT
_BINARYMETRICS.fields_by_name['roc_curve'].message_type = _ROC
_BINARYMETRICS.fields_by_name['precision_recall_curve'].message_type = _PRECISIONRECALLCURVE
_EVALTESTSETENTRY.fields_by_name['predicted_concepts'].message_type = proto_dot_clarifai_dot_api_dot_concept__pb2._CONCEPT
_EVALTESTSETENTRY.fields_by_name['ground_truth_concepts'].message_type = proto_dot_clarifai_dot_api_dot_concept__pb2._CONCEPT
_EVALMETRICS.fields_by_name['status'].message_type = proto_dot_clarifai_dot_api_dot_status_dot_status__pb2._STATUS
_EVALMETRICS.fields_by_name['summary'].message_type = _METRICSSUMMARY
_EVALMETRICS.fields_by_name['confusion_matrix'].message_type = _CONFUSIONMATRIX
_EVALMETRICS.fields_by_name['cooccurrence_matrix'].message_type = _COOCCURRENCEMATRIX
_EVALMETRICS.fields_by_name['label_counts'].message_type = _LABELDISTRIBUTION
_EVALMETRICS.fields_by_name['binary_metrics'].message_type = _BINARYMETRICS
_EVALMETRICS.fields_by_name['test_set'].message_type = _EVALTESTSETENTRY
_GETMODELVERSIONMETRICSREQUEST_FIELDSVALUE.containing_type = _GETMODELVERSIONMETRICSREQUEST
_GETMODELVERSIONMETRICSREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_GETMODELVERSIONMETRICSREQUEST.fields_by_name['fields'].message_type = _GETMODELVERSIONMETRICSREQUEST_FIELDSVALUE
_POSTMODELVERSIONMETRICSREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
DESCRIPTOR.message_types_by_name['ModelVersion'] = _MODELVERSION
DESCRIPTOR.message_types_by_name['PretrainedModelConfig'] = _PRETRAINEDMODELCONFIG
DESCRIPTOR.message_types_by_name['GetModelVersionRequest'] = _GETMODELVERSIONREQUEST
DESCRIPTOR.message_types_by_name['ListModelVersionsRequest'] = _LISTMODELVERSIONSREQUEST
DESCRIPTOR.message_types_by_name['PostModelVersionsRequest'] = _POSTMODELVERSIONSREQUEST
DESCRIPTOR.message_types_by_name['DeleteModelVersionRequest'] = _DELETEMODELVERSIONREQUEST
DESCRIPTOR.message_types_by_name['SingleModelVersionResponse'] = _SINGLEMODELVERSIONRESPONSE
DESCRIPTOR.message_types_by_name['MultiModelVersionResponse'] = _MULTIMODELVERSIONRESPONSE
DESCRIPTOR.message_types_by_name['LabelCount'] = _LABELCOUNT
DESCRIPTOR.message_types_by_name['LabelDistribution'] = _LABELDISTRIBUTION
DESCRIPTOR.message_types_by_name['CooccurrenceMatrixEntry'] = _COOCCURRENCEMATRIXENTRY
DESCRIPTOR.message_types_by_name['CooccurrenceMatrix'] = _COOCCURRENCEMATRIX
DESCRIPTOR.message_types_by_name['ConfusionMatrixEntry'] = _CONFUSIONMATRIXENTRY
DESCRIPTOR.message_types_by_name['ConfusionMatrix'] = _CONFUSIONMATRIX
DESCRIPTOR.message_types_by_name['ROC'] = _ROC
DESCRIPTOR.message_types_by_name['PrecisionRecallCurve'] = _PRECISIONRECALLCURVE
DESCRIPTOR.message_types_by_name['BinaryMetrics'] = _BINARYMETRICS
DESCRIPTOR.message_types_by_name['EvalTestSetEntry'] = _EVALTESTSETENTRY
DESCRIPTOR.message_types_by_name['MetricsSummary'] = _METRICSSUMMARY
DESCRIPTOR.message_types_by_name['EvalMetrics'] = _EVALMETRICS
DESCRIPTOR.message_types_by_name['GetModelVersionMetricsRequest'] = _GETMODELVERSIONMETRICSREQUEST
DESCRIPTOR.message_types_by_name['PostModelVersionMetricsRequest'] = _POSTMODELVERSIONMETRICSREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ModelVersion = _reflection.GeneratedProtocolMessageType('ModelVersion', (_message.Message,), dict(
  DESCRIPTOR = _MODELVERSION,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.ModelVersion)
  ))
_sym_db.RegisterMessage(ModelVersion)

PretrainedModelConfig = _reflection.GeneratedProtocolMessageType('PretrainedModelConfig', (_message.Message,), dict(
  DESCRIPTOR = _PRETRAINEDMODELCONFIG,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.PretrainedModelConfig)
  ))
_sym_db.RegisterMessage(PretrainedModelConfig)

GetModelVersionRequest = _reflection.GeneratedProtocolMessageType('GetModelVersionRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETMODELVERSIONREQUEST,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.GetModelVersionRequest)
  ))
_sym_db.RegisterMessage(GetModelVersionRequest)

ListModelVersionsRequest = _reflection.GeneratedProtocolMessageType('ListModelVersionsRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTMODELVERSIONSREQUEST,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.ListModelVersionsRequest)
  ))
_sym_db.RegisterMessage(ListModelVersionsRequest)

PostModelVersionsRequest = _reflection.GeneratedProtocolMessageType('PostModelVersionsRequest', (_message.Message,), dict(
  DESCRIPTOR = _POSTMODELVERSIONSREQUEST,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.PostModelVersionsRequest)
  ))
_sym_db.RegisterMessage(PostModelVersionsRequest)

DeleteModelVersionRequest = _reflection.GeneratedProtocolMessageType('DeleteModelVersionRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEMODELVERSIONREQUEST,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.DeleteModelVersionRequest)
  ))
_sym_db.RegisterMessage(DeleteModelVersionRequest)

SingleModelVersionResponse = _reflection.GeneratedProtocolMessageType('SingleModelVersionResponse', (_message.Message,), dict(
  DESCRIPTOR = _SINGLEMODELVERSIONRESPONSE,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.SingleModelVersionResponse)
  ))
_sym_db.RegisterMessage(SingleModelVersionResponse)

MultiModelVersionResponse = _reflection.GeneratedProtocolMessageType('MultiModelVersionResponse', (_message.Message,), dict(
  DESCRIPTOR = _MULTIMODELVERSIONRESPONSE,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.MultiModelVersionResponse)
  ))
_sym_db.RegisterMessage(MultiModelVersionResponse)

LabelCount = _reflection.GeneratedProtocolMessageType('LabelCount', (_message.Message,), dict(
  DESCRIPTOR = _LABELCOUNT,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.LabelCount)
  ))
_sym_db.RegisterMessage(LabelCount)

LabelDistribution = _reflection.GeneratedProtocolMessageType('LabelDistribution', (_message.Message,), dict(
  DESCRIPTOR = _LABELDISTRIBUTION,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.LabelDistribution)
  ))
_sym_db.RegisterMessage(LabelDistribution)

CooccurrenceMatrixEntry = _reflection.GeneratedProtocolMessageType('CooccurrenceMatrixEntry', (_message.Message,), dict(
  DESCRIPTOR = _COOCCURRENCEMATRIXENTRY,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.CooccurrenceMatrixEntry)
  ))
_sym_db.RegisterMessage(CooccurrenceMatrixEntry)

CooccurrenceMatrix = _reflection.GeneratedProtocolMessageType('CooccurrenceMatrix', (_message.Message,), dict(
  DESCRIPTOR = _COOCCURRENCEMATRIX,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.CooccurrenceMatrix)
  ))
_sym_db.RegisterMessage(CooccurrenceMatrix)

ConfusionMatrixEntry = _reflection.GeneratedProtocolMessageType('ConfusionMatrixEntry', (_message.Message,), dict(
  DESCRIPTOR = _CONFUSIONMATRIXENTRY,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.ConfusionMatrixEntry)
  ))
_sym_db.RegisterMessage(ConfusionMatrixEntry)

ConfusionMatrix = _reflection.GeneratedProtocolMessageType('ConfusionMatrix', (_message.Message,), dict(
  DESCRIPTOR = _CONFUSIONMATRIX,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.ConfusionMatrix)
  ))
_sym_db.RegisterMessage(ConfusionMatrix)

ROC = _reflection.GeneratedProtocolMessageType('ROC', (_message.Message,), dict(
  DESCRIPTOR = _ROC,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.ROC)
  ))
_sym_db.RegisterMessage(ROC)

PrecisionRecallCurve = _reflection.GeneratedProtocolMessageType('PrecisionRecallCurve', (_message.Message,), dict(
  DESCRIPTOR = _PRECISIONRECALLCURVE,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.PrecisionRecallCurve)
  ))
_sym_db.RegisterMessage(PrecisionRecallCurve)

BinaryMetrics = _reflection.GeneratedProtocolMessageType('BinaryMetrics', (_message.Message,), dict(
  DESCRIPTOR = _BINARYMETRICS,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.BinaryMetrics)
  ))
_sym_db.RegisterMessage(BinaryMetrics)

EvalTestSetEntry = _reflection.GeneratedProtocolMessageType('EvalTestSetEntry', (_message.Message,), dict(
  DESCRIPTOR = _EVALTESTSETENTRY,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.EvalTestSetEntry)
  ))
_sym_db.RegisterMessage(EvalTestSetEntry)

MetricsSummary = _reflection.GeneratedProtocolMessageType('MetricsSummary', (_message.Message,), dict(
  DESCRIPTOR = _METRICSSUMMARY,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.MetricsSummary)
  ))
_sym_db.RegisterMessage(MetricsSummary)

EvalMetrics = _reflection.GeneratedProtocolMessageType('EvalMetrics', (_message.Message,), dict(
  DESCRIPTOR = _EVALMETRICS,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.EvalMetrics)
  ))
_sym_db.RegisterMessage(EvalMetrics)

GetModelVersionMetricsRequest = _reflection.GeneratedProtocolMessageType('GetModelVersionMetricsRequest', (_message.Message,), dict(

  FieldsValue = _reflection.GeneratedProtocolMessageType('FieldsValue', (_message.Message,), dict(
    DESCRIPTOR = _GETMODELVERSIONMETRICSREQUEST_FIELDSVALUE,
    __module__ = 'proto.clarifai.api.model_version_pb2'
    # @@protoc_insertion_point(class_scope:clarifai.api.GetModelVersionMetricsRequest.FieldsValue)
    ))
  ,
  DESCRIPTOR = _GETMODELVERSIONMETRICSREQUEST,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.GetModelVersionMetricsRequest)
  ))
_sym_db.RegisterMessage(GetModelVersionMetricsRequest)
_sym_db.RegisterMessage(GetModelVersionMetricsRequest.FieldsValue)

PostModelVersionMetricsRequest = _reflection.GeneratedProtocolMessageType('PostModelVersionMetricsRequest', (_message.Message,), dict(
  DESCRIPTOR = _POSTMODELVERSIONMETRICSREQUEST,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.PostModelVersionMetricsRequest)
  ))
_sym_db.RegisterMessage(PostModelVersionMetricsRequest)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('Z\003api\242\002\004CAIP\302\002\001_\312\002\021Clarifai\\Internal'))
_MULTIMODELVERSIONRESPONSE.fields_by_name['model_versions'].has_options = True
_MULTIMODELVERSIONRESPONSE.fields_by_name['model_versions']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\265\030\001'))
_METRICSSUMMARY.fields_by_name['top1_accuracy'].has_options = True
_METRICSSUMMARY.fields_by_name['top1_accuracy']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_METRICSSUMMARY.fields_by_name['top5_accuracy'].has_options = True
_METRICSSUMMARY.fields_by_name['top5_accuracy']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
# @@protoc_insertion_point(module_scope)
