# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from clarifai.rest.grpc.proto.clarifai.api import code_pb2 as proto_dot_clarifai_dot_api_dot_code__pb2
from clarifai.rest.grpc.proto.clarifai.api import concept_graph_pb2 as proto_dot_clarifai_dot_api_dot_concept__graph__pb2
from clarifai.rest.grpc.proto.clarifai.api import concept_language_pb2 as proto_dot_clarifai_dot_api_dot_concept__language__pb2
from clarifai.rest.grpc.proto.clarifai.api import concept_pb2 as proto_dot_clarifai_dot_api_dot_concept__pb2
from clarifai.rest.grpc.proto.clarifai.api import concept_reference_pb2 as proto_dot_clarifai_dot_api_dot_concept__reference__pb2
from clarifai.rest.grpc.proto.clarifai.api import endpoint_pb2 as proto_dot_clarifai_dot_api_dot_endpoint__pb2
from clarifai.rest.grpc.proto.clarifai.api import healthz_pb2 as proto_dot_clarifai_dot_api_dot_healthz__pb2
from clarifai.rest.grpc.proto.clarifai.api import input_pb2 as proto_dot_clarifai_dot_api_dot_input__pb2
from clarifai.rest.grpc.proto.clarifai.api import model_pb2 as proto_dot_clarifai_dot_api_dot_model__pb2
from clarifai.rest.grpc.proto.clarifai.api import model_version_pb2 as proto_dot_clarifai_dot_api_dot_model__version__pb2
from clarifai.rest.grpc.proto.clarifai.api import output_pb2 as proto_dot_clarifai_dot_api_dot_output__pb2
from clarifai.rest.grpc.proto.clarifai.api import search_pb2 as proto_dot_clarifai_dot_api_dot_search__pb2
from clarifai.rest.grpc.proto.clarifai.api.status import status_pb2 as proto_dot_clarifai_dot_api_dot_status_dot_status__pb2
from clarifai.rest.grpc.proto.clarifai.api import subscription_pb2 as proto_dot_clarifai_dot_api_dot_subscription__pb2
from clarifai.rest.grpc.proto.clarifai.api import visualization_pb2 as proto_dot_clarifai_dot_api_dot_visualization__pb2
from clarifai.rest.grpc.proto.clarifai.api import vocab_pb2 as proto_dot_clarifai_dot_api_dot_vocab__pb2
from clarifai.rest.grpc.proto.clarifai.api import workflow_pb2 as proto_dot_clarifai_dot_api_dot_workflow__pb2


class V2Stub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Echo = channel.unary_unary(
        '/clarifai.api.V2/Echo',
        request_serializer=proto_dot_clarifai_dot_api_dot_endpoint__pb2.TestMessage.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_endpoint__pb2.TestMessage,
        )
    self.GetConceptCounts = channel.unary_unary(
        '/clarifai.api.V2/GetConceptCounts',
        request_serializer=proto_dot_clarifai_dot_api_dot_concept__pb2.GetConceptCountsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_concept__pb2.MultiConceptCountResponse,
        )
    self.GetConcept = channel.unary_unary(
        '/clarifai.api.V2/GetConcept',
        request_serializer=proto_dot_clarifai_dot_api_dot_concept__pb2.GetConceptRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_concept__pb2.SingleConceptResponse,
        )
    self.ListConcepts = channel.unary_unary(
        '/clarifai.api.V2/ListConcepts',
        request_serializer=proto_dot_clarifai_dot_api_dot_concept__pb2.ListConceptsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_concept__pb2.MultiConceptResponse,
        )
    self.PostConceptsSearches = channel.unary_unary(
        '/clarifai.api.V2/PostConceptsSearches',
        request_serializer=proto_dot_clarifai_dot_api_dot_concept__pb2.PostConceptsSearchesRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_concept__pb2.MultiConceptResponse,
        )
    self.PostConcepts = channel.unary_unary(
        '/clarifai.api.V2/PostConcepts',
        request_serializer=proto_dot_clarifai_dot_api_dot_concept__pb2.PostConceptsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_concept__pb2.MultiConceptResponse,
        )
    self.PatchConcepts = channel.unary_unary(
        '/clarifai.api.V2/PatchConcepts',
        request_serializer=proto_dot_clarifai_dot_api_dot_concept__pb2.PatchConceptsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_concept__pb2.MultiConceptResponse,
        )
    self.GetVocab = channel.unary_unary(
        '/clarifai.api.V2/GetVocab',
        request_serializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.GetVocabRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.SingleVocabResponse,
        )
    self.ListVocabs = channel.unary_unary(
        '/clarifai.api.V2/ListVocabs',
        request_serializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.ListVocabsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.MultiVocabResponse,
        )
    self.PostVocabs = channel.unary_unary(
        '/clarifai.api.V2/PostVocabs',
        request_serializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.PostVocabsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.MultiVocabResponse,
        )
    self.PatchVocabs = channel.unary_unary(
        '/clarifai.api.V2/PatchVocabs',
        request_serializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.PatchVocabsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.MultiVocabResponse,
        )
    self.DeleteVocab = channel.unary_unary(
        '/clarifai.api.V2/DeleteVocab',
        request_serializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.DeleteVocabRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse,
        )
    self.DeleteVocabs = channel.unary_unary(
        '/clarifai.api.V2/DeleteVocabs',
        request_serializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.DeleteVocabsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse,
        )
    self.ListVocabConcepts = channel.unary_unary(
        '/clarifai.api.V2/ListVocabConcepts',
        request_serializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.ListVocabConceptsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_concept__pb2.MultiConceptResponse,
        )
    self.PostVocabConcepts = channel.unary_unary(
        '/clarifai.api.V2/PostVocabConcepts',
        request_serializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.PostVocabConceptsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_concept__pb2.MultiConceptResponse,
        )
    self.DeleteVocabConcept = channel.unary_unary(
        '/clarifai.api.V2/DeleteVocabConcept',
        request_serializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.DeleteVocabConceptRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse,
        )
    self.DeleteVocabConcepts = channel.unary_unary(
        '/clarifai.api.V2/DeleteVocabConcepts',
        request_serializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.DeleteVocabConceptsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse,
        )
    self.GetConceptLanguage = channel.unary_unary(
        '/clarifai.api.V2/GetConceptLanguage',
        request_serializer=proto_dot_clarifai_dot_api_dot_concept__language__pb2.GetConceptLanguageRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_concept__language__pb2.SingleConceptLanguageResponse,
        )
    self.ListConceptLanguages = channel.unary_unary(
        '/clarifai.api.V2/ListConceptLanguages',
        request_serializer=proto_dot_clarifai_dot_api_dot_concept__language__pb2.ListConceptLanguagesRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_concept__language__pb2.MultiConceptLanguageResponse,
        )
    self.PostConceptLanguages = channel.unary_unary(
        '/clarifai.api.V2/PostConceptLanguages',
        request_serializer=proto_dot_clarifai_dot_api_dot_concept__language__pb2.PostConceptLanguagesRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_concept__language__pb2.MultiConceptLanguageResponse,
        )
    self.PatchConceptLanguages = channel.unary_unary(
        '/clarifai.api.V2/PatchConceptLanguages',
        request_serializer=proto_dot_clarifai_dot_api_dot_concept__language__pb2.PatchConceptLanguagesRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_concept__language__pb2.MultiConceptLanguageResponse,
        )
    self.ListConceptReferences = channel.unary_unary(
        '/clarifai.api.V2/ListConceptReferences',
        request_serializer=proto_dot_clarifai_dot_api_dot_concept__reference__pb2.ListConceptReferencesRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_concept__reference__pb2.MultiConceptReferenceResponse,
        )
    self.ListConceptRelations = channel.unary_unary(
        '/clarifai.api.V2/ListConceptRelations',
        request_serializer=proto_dot_clarifai_dot_api_dot_concept__graph__pb2.ListConceptRelationsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_concept__pb2.MultiConceptResponse,
        )
    self.GetInputCount = channel.unary_unary(
        '/clarifai.api.V2/GetInputCount',
        request_serializer=proto_dot_clarifai_dot_api_dot_input__pb2.GetInputCountRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_input__pb2.SingleInputCountResponse,
        )
    self.StreamInputs = channel.unary_unary(
        '/clarifai.api.V2/StreamInputs',
        request_serializer=proto_dot_clarifai_dot_api_dot_input__pb2.StreamInputsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_input__pb2.MultiInputResponse,
        )
    self.GetInput = channel.unary_unary(
        '/clarifai.api.V2/GetInput',
        request_serializer=proto_dot_clarifai_dot_api_dot_input__pb2.GetInputRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_input__pb2.SingleInputResponse,
        )
    self.ListInputs = channel.unary_unary(
        '/clarifai.api.V2/ListInputs',
        request_serializer=proto_dot_clarifai_dot_api_dot_input__pb2.ListInputsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_input__pb2.MultiInputResponse,
        )
    self.PostInputs = channel.unary_unary(
        '/clarifai.api.V2/PostInputs',
        request_serializer=proto_dot_clarifai_dot_api_dot_input__pb2.PostInputsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_input__pb2.MultiInputResponse,
        )
    self.PatchInputs = channel.unary_unary(
        '/clarifai.api.V2/PatchInputs',
        request_serializer=proto_dot_clarifai_dot_api_dot_input__pb2.PatchInputsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_input__pb2.MultiInputResponse,
        )
    self.DeleteInput = channel.unary_unary(
        '/clarifai.api.V2/DeleteInput',
        request_serializer=proto_dot_clarifai_dot_api_dot_input__pb2.DeleteInputRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse,
        )
    self.DeleteInputs = channel.unary_unary(
        '/clarifai.api.V2/DeleteInputs',
        request_serializer=proto_dot_clarifai_dot_api_dot_input__pb2.DeleteInputsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse,
        )
    self.PostModelOutputs = channel.unary_unary(
        '/clarifai.api.V2/PostModelOutputs',
        request_serializer=proto_dot_clarifai_dot_api_dot_input__pb2.PostModelOutputsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_output__pb2.MultiOutputResponse,
        )
    self.PostModelFeedback = channel.unary_unary(
        '/clarifai.api.V2/PostModelFeedback',
        request_serializer=proto_dot_clarifai_dot_api_dot_input__pb2.PostModelFeedbackRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse,
        )
    self.GetModel = channel.unary_unary(
        '/clarifai.api.V2/GetModel',
        request_serializer=proto_dot_clarifai_dot_api_dot_model__pb2.GetModelRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_model__pb2.SingleModelResponse,
        )
    self.GetModelOutputInfo = channel.unary_unary(
        '/clarifai.api.V2/GetModelOutputInfo',
        request_serializer=proto_dot_clarifai_dot_api_dot_model__pb2.GetModelRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_model__pb2.SingleModelResponse,
        )
    self.ListModels = channel.unary_unary(
        '/clarifai.api.V2/ListModels',
        request_serializer=proto_dot_clarifai_dot_api_dot_model__pb2.ListModelsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_model__pb2.MultiModelResponse,
        )
    self.PostModelsSearches = channel.unary_unary(
        '/clarifai.api.V2/PostModelsSearches',
        request_serializer=proto_dot_clarifai_dot_api_dot_model__pb2.PostModelsSearchesRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_model__pb2.MultiModelResponse,
        )
    self.PostModels = channel.unary_unary(
        '/clarifai.api.V2/PostModels',
        request_serializer=proto_dot_clarifai_dot_api_dot_model__pb2.PostModelsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_model__pb2.SingleModelResponse,
        )
    self.PatchModels = channel.unary_unary(
        '/clarifai.api.V2/PatchModels',
        request_serializer=proto_dot_clarifai_dot_api_dot_model__pb2.PatchModelsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_model__pb2.MultiModelResponse,
        )
    self.DeleteModel = channel.unary_unary(
        '/clarifai.api.V2/DeleteModel',
        request_serializer=proto_dot_clarifai_dot_api_dot_model__pb2.DeleteModelRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse,
        )
    self.DeleteModels = channel.unary_unary(
        '/clarifai.api.V2/DeleteModels',
        request_serializer=proto_dot_clarifai_dot_api_dot_model__pb2.DeleteModelsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse,
        )
    self.ListModelInputs = channel.unary_unary(
        '/clarifai.api.V2/ListModelInputs',
        request_serializer=proto_dot_clarifai_dot_api_dot_input__pb2.ListModelInputsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_input__pb2.MultiInputResponse,
        )
    self.GetModelVersion = channel.unary_unary(
        '/clarifai.api.V2/GetModelVersion',
        request_serializer=proto_dot_clarifai_dot_api_dot_model__version__pb2.GetModelVersionRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_model__version__pb2.SingleModelVersionResponse,
        )
    self.ListModelVersions = channel.unary_unary(
        '/clarifai.api.V2/ListModelVersions',
        request_serializer=proto_dot_clarifai_dot_api_dot_model__version__pb2.ListModelVersionsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_model__version__pb2.MultiModelVersionResponse,
        )
    self.PostModelVersions = channel.unary_unary(
        '/clarifai.api.V2/PostModelVersions',
        request_serializer=proto_dot_clarifai_dot_api_dot_model__version__pb2.PostModelVersionsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_model__pb2.SingleModelResponse,
        )
    self.DeleteModelVersion = channel.unary_unary(
        '/clarifai.api.V2/DeleteModelVersion',
        request_serializer=proto_dot_clarifai_dot_api_dot_model__version__pb2.DeleteModelVersionRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse,
        )
    self.GetModelVersionMetrics = channel.unary_unary(
        '/clarifai.api.V2/GetModelVersionMetrics',
        request_serializer=proto_dot_clarifai_dot_api_dot_model__version__pb2.GetModelVersionMetricsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_model__version__pb2.SingleModelVersionResponse,
        )
    self.PostModelVersionMetrics = channel.unary_unary(
        '/clarifai.api.V2/PostModelVersionMetrics',
        request_serializer=proto_dot_clarifai_dot_api_dot_model__version__pb2.PostModelVersionMetricsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_model__version__pb2.SingleModelVersionResponse,
        )
    self.GetWorkflow = channel.unary_unary(
        '/clarifai.api.V2/GetWorkflow',
        request_serializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.GetWorkflowRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.SingleWorkflowResponse,
        )
    self.ListWorkflows = channel.unary_unary(
        '/clarifai.api.V2/ListWorkflows',
        request_serializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.ListWorkflowsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.MultiWorkflowResponse,
        )
    self.ListPublicWorkflows = channel.unary_unary(
        '/clarifai.api.V2/ListPublicWorkflows',
        request_serializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.ListPublicWorkflowsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.MultiWorkflowResponse,
        )
    self.PostWorkflows = channel.unary_unary(
        '/clarifai.api.V2/PostWorkflows',
        request_serializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.PostWorkflowsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.MultiWorkflowResponse,
        )
    self.PatchWorkflows = channel.unary_unary(
        '/clarifai.api.V2/PatchWorkflows',
        request_serializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.PatchWorkflowsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.MultiWorkflowResponse,
        )
    self.DeleteWorkflow = channel.unary_unary(
        '/clarifai.api.V2/DeleteWorkflow',
        request_serializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.DeleteWorkflowRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse,
        )
    self.DeleteWorkflows = channel.unary_unary(
        '/clarifai.api.V2/DeleteWorkflows',
        request_serializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.DeleteWorkflowsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse,
        )
    self.PostWorkflowResults = channel.unary_unary(
        '/clarifai.api.V2/PostWorkflowResults',
        request_serializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.PostWorkflowResultsRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.PostWorkflowResultsResponse,
        )
    self.PostSearches = channel.unary_unary(
        '/clarifai.api.V2/PostSearches',
        request_serializer=proto_dot_clarifai_dot_api_dot_search__pb2.PostSearchesRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_search__pb2.MultiSearchResponse,
        )
    self.PostSearchFeedback = channel.unary_unary(
        '/clarifai.api.V2/PostSearchFeedback',
        request_serializer=proto_dot_clarifai_dot_api_dot_search__pb2.PostSearchFeedbackRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse,
        )
    self.GetSubscription = channel.unary_unary(
        '/clarifai.api.V2/GetSubscription',
        request_serializer=proto_dot_clarifai_dot_api_dot_subscription__pb2.GetSubscriptionRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_subscription__pb2.SingleSubscriptionResponse,
        )
    self.PostSubscription = channel.unary_unary(
        '/clarifai.api.V2/PostSubscription',
        request_serializer=proto_dot_clarifai_dot_api_dot_subscription__pb2.PostSubscriptionRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_subscription__pb2.SingleSubscriptionResponse,
        )
    self.GetAppVisualization = channel.unary_unary(
        '/clarifai.api.V2/GetAppVisualization',
        request_serializer=proto_dot_clarifai_dot_api_dot_visualization__pb2.GetAppVisualizationRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_visualization__pb2.SingleVisualizationResponse,
        )
    self.GetVisualization = channel.unary_unary(
        '/clarifai.api.V2/GetVisualization',
        request_serializer=proto_dot_clarifai_dot_api_dot_visualization__pb2.GetVisualizationRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_visualization__pb2.SingleVisualizationResponse,
        )
    self.PostVisualization = channel.unary_unary(
        '/clarifai.api.V2/PostVisualization',
        request_serializer=proto_dot_clarifai_dot_api_dot_visualization__pb2.PostVisualizationRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_visualization__pb2.SingleVisualizationResponse,
        )
    self.ListStatusCodes = channel.unary_unary(
        '/clarifai.api.V2/ListStatusCodes',
        request_serializer=proto_dot_clarifai_dot_api_dot_code__pb2.ListStatusCodesRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_code__pb2.MultiStatusCodeResponse,
        )
    self.GetStatusCode = channel.unary_unary(
        '/clarifai.api.V2/GetStatusCode',
        request_serializer=proto_dot_clarifai_dot_api_dot_code__pb2.GetStatusCodeRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_code__pb2.SingleStatusCodeResponse,
        )
    self.GetHealthz = channel.unary_unary(
        '/clarifai.api.V2/GetHealthz',
        request_serializer=proto_dot_clarifai_dot_api_dot_healthz__pb2.GetHealthzRequest.SerializeToString,
        response_deserializer=proto_dot_clarifai_dot_api_dot_healthz__pb2.GetHealthzResponse,
        )


class V2Servicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Echo(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetConceptCounts(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetConcept(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListConcepts(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PostConceptsSearches(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PostConcepts(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PatchConcepts(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetVocab(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListVocabs(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PostVocabs(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PatchVocabs(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteVocab(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteVocabs(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListVocabConcepts(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PostVocabConcepts(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteVocabConcept(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteVocabConcepts(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetConceptLanguage(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListConceptLanguages(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PostConceptLanguages(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PatchConceptLanguages(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListConceptReferences(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListConceptRelations(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetInputCount(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def StreamInputs(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetInput(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListInputs(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PostInputs(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PatchInputs(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteInput(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteInputs(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PostModelOutputs(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PostModelFeedback(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetModel(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetModelOutputInfo(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListModels(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PostModelsSearches(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PostModels(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PatchModels(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteModel(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteModels(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListModelInputs(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetModelVersion(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListModelVersions(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PostModelVersions(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteModelVersion(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetModelVersionMetrics(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PostModelVersionMetrics(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetWorkflow(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListWorkflows(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListPublicWorkflows(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PostWorkflows(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PatchWorkflows(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteWorkflow(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteWorkflows(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PostWorkflowResults(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PostSearches(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PostSearchFeedback(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetSubscription(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PostSubscription(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetAppVisualization(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetVisualization(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PostVisualization(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListStatusCodes(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetStatusCode(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetHealthz(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_V2Servicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Echo': grpc.unary_unary_rpc_method_handler(
          servicer.Echo,
          request_deserializer=proto_dot_clarifai_dot_api_dot_endpoint__pb2.TestMessage,
          response_serializer=proto_dot_clarifai_dot_api_dot_endpoint__pb2.TestMessage.SerializeToString,
      ),
      'GetConceptCounts': grpc.unary_unary_rpc_method_handler(
          servicer.GetConceptCounts,
          request_deserializer=proto_dot_clarifai_dot_api_dot_concept__pb2.GetConceptCountsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_concept__pb2.MultiConceptCountResponse.SerializeToString,
      ),
      'GetConcept': grpc.unary_unary_rpc_method_handler(
          servicer.GetConcept,
          request_deserializer=proto_dot_clarifai_dot_api_dot_concept__pb2.GetConceptRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_concept__pb2.SingleConceptResponse.SerializeToString,
      ),
      'ListConcepts': grpc.unary_unary_rpc_method_handler(
          servicer.ListConcepts,
          request_deserializer=proto_dot_clarifai_dot_api_dot_concept__pb2.ListConceptsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_concept__pb2.MultiConceptResponse.SerializeToString,
      ),
      'PostConceptsSearches': grpc.unary_unary_rpc_method_handler(
          servicer.PostConceptsSearches,
          request_deserializer=proto_dot_clarifai_dot_api_dot_concept__pb2.PostConceptsSearchesRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_concept__pb2.MultiConceptResponse.SerializeToString,
      ),
      'PostConcepts': grpc.unary_unary_rpc_method_handler(
          servicer.PostConcepts,
          request_deserializer=proto_dot_clarifai_dot_api_dot_concept__pb2.PostConceptsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_concept__pb2.MultiConceptResponse.SerializeToString,
      ),
      'PatchConcepts': grpc.unary_unary_rpc_method_handler(
          servicer.PatchConcepts,
          request_deserializer=proto_dot_clarifai_dot_api_dot_concept__pb2.PatchConceptsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_concept__pb2.MultiConceptResponse.SerializeToString,
      ),
      'GetVocab': grpc.unary_unary_rpc_method_handler(
          servicer.GetVocab,
          request_deserializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.GetVocabRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.SingleVocabResponse.SerializeToString,
      ),
      'ListVocabs': grpc.unary_unary_rpc_method_handler(
          servicer.ListVocabs,
          request_deserializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.ListVocabsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.MultiVocabResponse.SerializeToString,
      ),
      'PostVocabs': grpc.unary_unary_rpc_method_handler(
          servicer.PostVocabs,
          request_deserializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.PostVocabsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.MultiVocabResponse.SerializeToString,
      ),
      'PatchVocabs': grpc.unary_unary_rpc_method_handler(
          servicer.PatchVocabs,
          request_deserializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.PatchVocabsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.MultiVocabResponse.SerializeToString,
      ),
      'DeleteVocab': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteVocab,
          request_deserializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.DeleteVocabRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse.SerializeToString,
      ),
      'DeleteVocabs': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteVocabs,
          request_deserializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.DeleteVocabsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse.SerializeToString,
      ),
      'ListVocabConcepts': grpc.unary_unary_rpc_method_handler(
          servicer.ListVocabConcepts,
          request_deserializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.ListVocabConceptsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_concept__pb2.MultiConceptResponse.SerializeToString,
      ),
      'PostVocabConcepts': grpc.unary_unary_rpc_method_handler(
          servicer.PostVocabConcepts,
          request_deserializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.PostVocabConceptsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_concept__pb2.MultiConceptResponse.SerializeToString,
      ),
      'DeleteVocabConcept': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteVocabConcept,
          request_deserializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.DeleteVocabConceptRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse.SerializeToString,
      ),
      'DeleteVocabConcepts': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteVocabConcepts,
          request_deserializer=proto_dot_clarifai_dot_api_dot_vocab__pb2.DeleteVocabConceptsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse.SerializeToString,
      ),
      'GetConceptLanguage': grpc.unary_unary_rpc_method_handler(
          servicer.GetConceptLanguage,
          request_deserializer=proto_dot_clarifai_dot_api_dot_concept__language__pb2.GetConceptLanguageRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_concept__language__pb2.SingleConceptLanguageResponse.SerializeToString,
      ),
      'ListConceptLanguages': grpc.unary_unary_rpc_method_handler(
          servicer.ListConceptLanguages,
          request_deserializer=proto_dot_clarifai_dot_api_dot_concept__language__pb2.ListConceptLanguagesRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_concept__language__pb2.MultiConceptLanguageResponse.SerializeToString,
      ),
      'PostConceptLanguages': grpc.unary_unary_rpc_method_handler(
          servicer.PostConceptLanguages,
          request_deserializer=proto_dot_clarifai_dot_api_dot_concept__language__pb2.PostConceptLanguagesRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_concept__language__pb2.MultiConceptLanguageResponse.SerializeToString,
      ),
      'PatchConceptLanguages': grpc.unary_unary_rpc_method_handler(
          servicer.PatchConceptLanguages,
          request_deserializer=proto_dot_clarifai_dot_api_dot_concept__language__pb2.PatchConceptLanguagesRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_concept__language__pb2.MultiConceptLanguageResponse.SerializeToString,
      ),
      'ListConceptReferences': grpc.unary_unary_rpc_method_handler(
          servicer.ListConceptReferences,
          request_deserializer=proto_dot_clarifai_dot_api_dot_concept__reference__pb2.ListConceptReferencesRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_concept__reference__pb2.MultiConceptReferenceResponse.SerializeToString,
      ),
      'ListConceptRelations': grpc.unary_unary_rpc_method_handler(
          servicer.ListConceptRelations,
          request_deserializer=proto_dot_clarifai_dot_api_dot_concept__graph__pb2.ListConceptRelationsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_concept__pb2.MultiConceptResponse.SerializeToString,
      ),
      'GetInputCount': grpc.unary_unary_rpc_method_handler(
          servicer.GetInputCount,
          request_deserializer=proto_dot_clarifai_dot_api_dot_input__pb2.GetInputCountRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_input__pb2.SingleInputCountResponse.SerializeToString,
      ),
      'StreamInputs': grpc.unary_unary_rpc_method_handler(
          servicer.StreamInputs,
          request_deserializer=proto_dot_clarifai_dot_api_dot_input__pb2.StreamInputsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_input__pb2.MultiInputResponse.SerializeToString,
      ),
      'GetInput': grpc.unary_unary_rpc_method_handler(
          servicer.GetInput,
          request_deserializer=proto_dot_clarifai_dot_api_dot_input__pb2.GetInputRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_input__pb2.SingleInputResponse.SerializeToString,
      ),
      'ListInputs': grpc.unary_unary_rpc_method_handler(
          servicer.ListInputs,
          request_deserializer=proto_dot_clarifai_dot_api_dot_input__pb2.ListInputsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_input__pb2.MultiInputResponse.SerializeToString,
      ),
      'PostInputs': grpc.unary_unary_rpc_method_handler(
          servicer.PostInputs,
          request_deserializer=proto_dot_clarifai_dot_api_dot_input__pb2.PostInputsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_input__pb2.MultiInputResponse.SerializeToString,
      ),
      'PatchInputs': grpc.unary_unary_rpc_method_handler(
          servicer.PatchInputs,
          request_deserializer=proto_dot_clarifai_dot_api_dot_input__pb2.PatchInputsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_input__pb2.MultiInputResponse.SerializeToString,
      ),
      'DeleteInput': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteInput,
          request_deserializer=proto_dot_clarifai_dot_api_dot_input__pb2.DeleteInputRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse.SerializeToString,
      ),
      'DeleteInputs': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteInputs,
          request_deserializer=proto_dot_clarifai_dot_api_dot_input__pb2.DeleteInputsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse.SerializeToString,
      ),
      'PostModelOutputs': grpc.unary_unary_rpc_method_handler(
          servicer.PostModelOutputs,
          request_deserializer=proto_dot_clarifai_dot_api_dot_input__pb2.PostModelOutputsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_output__pb2.MultiOutputResponse.SerializeToString,
      ),
      'PostModelFeedback': grpc.unary_unary_rpc_method_handler(
          servicer.PostModelFeedback,
          request_deserializer=proto_dot_clarifai_dot_api_dot_input__pb2.PostModelFeedbackRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse.SerializeToString,
      ),
      'GetModel': grpc.unary_unary_rpc_method_handler(
          servicer.GetModel,
          request_deserializer=proto_dot_clarifai_dot_api_dot_model__pb2.GetModelRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_model__pb2.SingleModelResponse.SerializeToString,
      ),
      'GetModelOutputInfo': grpc.unary_unary_rpc_method_handler(
          servicer.GetModelOutputInfo,
          request_deserializer=proto_dot_clarifai_dot_api_dot_model__pb2.GetModelRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_model__pb2.SingleModelResponse.SerializeToString,
      ),
      'ListModels': grpc.unary_unary_rpc_method_handler(
          servicer.ListModels,
          request_deserializer=proto_dot_clarifai_dot_api_dot_model__pb2.ListModelsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_model__pb2.MultiModelResponse.SerializeToString,
      ),
      'PostModelsSearches': grpc.unary_unary_rpc_method_handler(
          servicer.PostModelsSearches,
          request_deserializer=proto_dot_clarifai_dot_api_dot_model__pb2.PostModelsSearchesRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_model__pb2.MultiModelResponse.SerializeToString,
      ),
      'PostModels': grpc.unary_unary_rpc_method_handler(
          servicer.PostModels,
          request_deserializer=proto_dot_clarifai_dot_api_dot_model__pb2.PostModelsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_model__pb2.SingleModelResponse.SerializeToString,
      ),
      'PatchModels': grpc.unary_unary_rpc_method_handler(
          servicer.PatchModels,
          request_deserializer=proto_dot_clarifai_dot_api_dot_model__pb2.PatchModelsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_model__pb2.MultiModelResponse.SerializeToString,
      ),
      'DeleteModel': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteModel,
          request_deserializer=proto_dot_clarifai_dot_api_dot_model__pb2.DeleteModelRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse.SerializeToString,
      ),
      'DeleteModels': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteModels,
          request_deserializer=proto_dot_clarifai_dot_api_dot_model__pb2.DeleteModelsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse.SerializeToString,
      ),
      'ListModelInputs': grpc.unary_unary_rpc_method_handler(
          servicer.ListModelInputs,
          request_deserializer=proto_dot_clarifai_dot_api_dot_input__pb2.ListModelInputsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_input__pb2.MultiInputResponse.SerializeToString,
      ),
      'GetModelVersion': grpc.unary_unary_rpc_method_handler(
          servicer.GetModelVersion,
          request_deserializer=proto_dot_clarifai_dot_api_dot_model__version__pb2.GetModelVersionRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_model__version__pb2.SingleModelVersionResponse.SerializeToString,
      ),
      'ListModelVersions': grpc.unary_unary_rpc_method_handler(
          servicer.ListModelVersions,
          request_deserializer=proto_dot_clarifai_dot_api_dot_model__version__pb2.ListModelVersionsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_model__version__pb2.MultiModelVersionResponse.SerializeToString,
      ),
      'PostModelVersions': grpc.unary_unary_rpc_method_handler(
          servicer.PostModelVersions,
          request_deserializer=proto_dot_clarifai_dot_api_dot_model__version__pb2.PostModelVersionsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_model__pb2.SingleModelResponse.SerializeToString,
      ),
      'DeleteModelVersion': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteModelVersion,
          request_deserializer=proto_dot_clarifai_dot_api_dot_model__version__pb2.DeleteModelVersionRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse.SerializeToString,
      ),
      'GetModelVersionMetrics': grpc.unary_unary_rpc_method_handler(
          servicer.GetModelVersionMetrics,
          request_deserializer=proto_dot_clarifai_dot_api_dot_model__version__pb2.GetModelVersionMetricsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_model__version__pb2.SingleModelVersionResponse.SerializeToString,
      ),
      'PostModelVersionMetrics': grpc.unary_unary_rpc_method_handler(
          servicer.PostModelVersionMetrics,
          request_deserializer=proto_dot_clarifai_dot_api_dot_model__version__pb2.PostModelVersionMetricsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_model__version__pb2.SingleModelVersionResponse.SerializeToString,
      ),
      'GetWorkflow': grpc.unary_unary_rpc_method_handler(
          servicer.GetWorkflow,
          request_deserializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.GetWorkflowRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.SingleWorkflowResponse.SerializeToString,
      ),
      'ListWorkflows': grpc.unary_unary_rpc_method_handler(
          servicer.ListWorkflows,
          request_deserializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.ListWorkflowsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.MultiWorkflowResponse.SerializeToString,
      ),
      'ListPublicWorkflows': grpc.unary_unary_rpc_method_handler(
          servicer.ListPublicWorkflows,
          request_deserializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.ListPublicWorkflowsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.MultiWorkflowResponse.SerializeToString,
      ),
      'PostWorkflows': grpc.unary_unary_rpc_method_handler(
          servicer.PostWorkflows,
          request_deserializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.PostWorkflowsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.MultiWorkflowResponse.SerializeToString,
      ),
      'PatchWorkflows': grpc.unary_unary_rpc_method_handler(
          servicer.PatchWorkflows,
          request_deserializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.PatchWorkflowsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.MultiWorkflowResponse.SerializeToString,
      ),
      'DeleteWorkflow': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteWorkflow,
          request_deserializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.DeleteWorkflowRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse.SerializeToString,
      ),
      'DeleteWorkflows': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteWorkflows,
          request_deserializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.DeleteWorkflowsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse.SerializeToString,
      ),
      'PostWorkflowResults': grpc.unary_unary_rpc_method_handler(
          servicer.PostWorkflowResults,
          request_deserializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.PostWorkflowResultsRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_workflow__pb2.PostWorkflowResultsResponse.SerializeToString,
      ),
      'PostSearches': grpc.unary_unary_rpc_method_handler(
          servicer.PostSearches,
          request_deserializer=proto_dot_clarifai_dot_api_dot_search__pb2.PostSearchesRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_search__pb2.MultiSearchResponse.SerializeToString,
      ),
      'PostSearchFeedback': grpc.unary_unary_rpc_method_handler(
          servicer.PostSearchFeedback,
          request_deserializer=proto_dot_clarifai_dot_api_dot_search__pb2.PostSearchFeedbackRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.BaseResponse.SerializeToString,
      ),
      'GetSubscription': grpc.unary_unary_rpc_method_handler(
          servicer.GetSubscription,
          request_deserializer=proto_dot_clarifai_dot_api_dot_subscription__pb2.GetSubscriptionRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_subscription__pb2.SingleSubscriptionResponse.SerializeToString,
      ),
      'PostSubscription': grpc.unary_unary_rpc_method_handler(
          servicer.PostSubscription,
          request_deserializer=proto_dot_clarifai_dot_api_dot_subscription__pb2.PostSubscriptionRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_subscription__pb2.SingleSubscriptionResponse.SerializeToString,
      ),
      'GetAppVisualization': grpc.unary_unary_rpc_method_handler(
          servicer.GetAppVisualization,
          request_deserializer=proto_dot_clarifai_dot_api_dot_visualization__pb2.GetAppVisualizationRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_visualization__pb2.SingleVisualizationResponse.SerializeToString,
      ),
      'GetVisualization': grpc.unary_unary_rpc_method_handler(
          servicer.GetVisualization,
          request_deserializer=proto_dot_clarifai_dot_api_dot_visualization__pb2.GetVisualizationRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_visualization__pb2.SingleVisualizationResponse.SerializeToString,
      ),
      'PostVisualization': grpc.unary_unary_rpc_method_handler(
          servicer.PostVisualization,
          request_deserializer=proto_dot_clarifai_dot_api_dot_visualization__pb2.PostVisualizationRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_visualization__pb2.SingleVisualizationResponse.SerializeToString,
      ),
      'ListStatusCodes': grpc.unary_unary_rpc_method_handler(
          servicer.ListStatusCodes,
          request_deserializer=proto_dot_clarifai_dot_api_dot_code__pb2.ListStatusCodesRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_code__pb2.MultiStatusCodeResponse.SerializeToString,
      ),
      'GetStatusCode': grpc.unary_unary_rpc_method_handler(
          servicer.GetStatusCode,
          request_deserializer=proto_dot_clarifai_dot_api_dot_code__pb2.GetStatusCodeRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_code__pb2.SingleStatusCodeResponse.SerializeToString,
      ),
      'GetHealthz': grpc.unary_unary_rpc_method_handler(
          servicer.GetHealthz,
          request_deserializer=proto_dot_clarifai_dot_api_dot_healthz__pb2.GetHealthzRequest,
          response_serializer=proto_dot_clarifai_dot_api_dot_healthz__pb2.GetHealthzResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'clarifai.api.V2', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
